#
#               Temperature and Bleaching Survival Index Analyses
#
# --------------------------------------------------------------------------- #
# R script to compute coral bleaching survival index (BSI) throughout the long
# heat stress experiment. This can be done using various other parameters which
# are set at the beginning of the script. This analysis also corrects BSI to
# correspond to accumulated heat stress rather than time.
# Note: R scripts in this repository should be run from 1 to 6 to avoid errors
# 
# Written by Liam Lachs, School of Natural and Environmental Sciences, Newcastle
# University, UK, on 01/08/2022, with contributions from Pawel 
# Palmowski.
# --------------------------------------------------------------------------- #


#Set threshold temperature (i.e. Use the opti_temp from the previous analysis or MMM)
stress_temp<-29.37082
MMM.adj=stress_temp
impute<-T
#number of previus values used for imputation with linear model, 3 is default	
#(3 is an arbitrary number, we can set it to whatever)	
lm_impute_number<-3	



library(dplyr)
library(tidyr)
library(scales)
library(grid)
library(gridExtra)
library(gridGraphics)
library(gplots)
library(ggplot2)
library(glmmTMB)
library(emmeans)
library(lubridate)
which.match = function(x,y){
  which(is.na(match(x,y))==FALSE)
}
binomial_smooth <- function(...) {
  geom_smooth(method = "glm", method.args = list(family = "binomial"), ...)
}





tank<-c(2,3,5,6) #these are the stress tanks
#Load measurement time points. File format:2 columns-Date, hours from 0.
log_times<-read.delim("data raw/log_times18.txt",header = FALSE,stringsAsFactors = FALSE)
#Convert dates to M/DD/YYYY format
log_times$V1<-gsub(" .*","",log_times$V1)
log_times$V1<-gsub("/18","/2018",log_times$V1)
log_times[3,1]<-"8/18/2018"
colnames(log_times)<-c("Sampling.Date","time")
log_times$Sampling.Date = mdy(log_times$Sampling.Date)
log_times$time<-log_times$time/(7*24) # convert to weeks

#Load a file containing temperature data for individual tanks. The file format 
#should contain a column named "time" containing information about the number 
#of hours from the start of the experiment
temp<-read.delim("data raw/merged18.txt",stringsAsFactors = FALSE)
temp = temp[c("time", "Tank.1", "Tank.2", "Tank.3", "Tank.4", "Tank.5", "Tank.6")]
temp$time<-temp$time/(7*24)
summary(temp$time)


# linear interpolation of some gaps
tempNA = temp
NA.rows = as.data.frame(which(is.na(temp) == TRUE, arr.ind = T))
head(NA.rows)
NA.rows$grp=NA
NA.rows$grp[1]=1
g=1
for(i in 2:nrow(NA.rows)){
  if(NA.rows$row[i] == (NA.rows$row[i-1]+1) &&
     NA.rows$col[i] == NA.rows$col[i-1]){
    NA.rows$grp[i] = g
  } else {
    g = g+1 
    NA.rows$grp[i] = g
  }
}

for(g in 1:max(NA.rows$grp)){
  NA.rows.sub = NA.rows[which(NA.rows$grp == g),]
  befaft = c(min(NA.rows.sub$row)-1, max(NA.rows.sub$row)+1)
  col=unique(NA.rows.sub$col)
  mod = lm(y~x,data=data.frame(y=temp[befaft,col],
                               x=temp[befaft,1]))
  temp[NA.rows.sub$row,col] =  predict(mod,newdata = data.frame(x=temp[NA.rows.sub$row,1]), se=F)
}



#Converting time from 0 to DHW
temp$DHW1<-as.numeric(rep(NA,nrow(temp)))
temp$DHW2<-as.numeric(rep(NA,nrow(temp)))
temp$DHW3<-as.numeric(rep(NA,nrow(temp)))
temp$DHW4<-as.numeric(rep(NA,nrow(temp)))
temp$DHW5<-as.numeric(rep(NA,nrow(temp)))
temp$DHW6<-as.numeric(rep(NA,nrow(temp)))

for(i in 8:13){
  temp[1,i]<-0
  for(j in 2:nrow(temp)){
    if(is.na(temp[j,i-6])){
      temp[j,i]<-NA
    }
    else{
      #Calculating mean temperature for current and previous time point
      temp[j,i]<-(temp[j,(i-6)]+temp[(j-1),(i-6)])/2
      #if the mean is higher than stress threshold then multiply the temp diff by time diff
      if(temp[j,i]>=stress_temp+1){
        temp[j,i]<-(temp[j,1]-temp[j-1,1])*(temp[j,i]-stress_temp)+temp[j-1,i]
      }
      #if the mean is lower DHW don't change
      else{
        temp[j,i]<-temp[j-1,i]
      }
    }
    
  }
}



# Plotting Tank DHWs
colnames(temp)

EX.T.v = gather(temp, "Tank", "SST", paste("Tank.",1:6,sep=""))
EX.T.v$Tank = recode(EX.T.v$Tank, Tank.1 = "T1",Tank.2 = "T2",Tank.3 = "T3",Tank.4 = "T4",Tank.5 = "T5", Tank.6 = "T6")
EX.T.v$Tank = factor(EX.T.v$Tank, levels=c("T2","T3","T5","T6", "T1","T4"))
colstouse=c("tan1","brown1","cornflowerblue","plum2","grey75","grey60")

F1A = 
  ggplot() + 
  geom_line(data = EX.T.v,
            aes(x = time,
                y = SST,
                group = Tank,
                colour = Tank),size=1) + 
  geom_hline(yintercept = MMM.adj, linetype = "dashed",size=1) + 
  geom_hline(yintercept = MMM.adj + 1, linetype = "solid",size=1) + 
  scale_colour_manual(values = colstouse) +
  labs(x = "Time (weeks)", 
       y = expression(paste("Temperature ("*degree*C*")"))) +
  ggplot2::annotate(geom = "text", x = 0.2, hjust = 0, y = 33.5, label = expression(paste(MMM[adj]*" + 1"*degree*C))) +
  ggplot2::annotate(geom = "text", x = 0.2, hjust = 0, y = 32.5, label = expression(paste(MMM[adj]))) +
  geom_line(data = data.frame(x = c(0, 0.15), y = 33.5), aes(x, y), linetype = "solid",size=1) + 
  geom_line(data = data.frame(x = c(0, 0.15), y = 32.5), aes(x, y), linetype = "dashed",size=1) + 
  coord_cartesian(clip="off") +
  theme_bw() + 
  theme(panel.grid = element_blank(),
        legend.position = "none",
        axis.title.y.right = element_text(face="bold"),
        axis.text.y.right = element_blank(),
        axis.ticks.y.right = element_blank(),
        plot.title = element_text(hjust=0.5))
F1A
save(F1A,file="data processed/Figure 1A - Temperature Profiles.Rdata")

EX.DHWs.v = gather(temp, "Tank", "DHW", paste("DHW",1:6,sep=""))
EX.DHWs.v$Tank = recode(EX.DHWs.v$Tank, DHW1 = "T1",DHW2 = "T2",DHW3 = "T3",DHW4 = "T4",DHW5 = "T5", DHW6 = "T6")
EX.DHWs.v$Tank = factor(EX.DHWs.v$Tank, levels=c("T2","T3","T5","T6", "T1","T4"))

F1B = 
  ggplot() + 
  geom_hline(yintercept = 0, linetype = "solid", colour = "grey92",size=1) + 
  geom_step(data = EX.DHWs.v,
            aes(x = time,
                y = DHW,
                group = Tank,
                colour = Tank),size=1) +
  scale_colour_manual(values = colstouse,
                      guide = guide_legend(title="Stress Tanks")) +
  labs(x = "Time (weeks)",
       y = expression(paste("DHW ("*degree*C*"-weeks)"))) +
  scale_y_continuous(limits = c(0,12),breaks=c(0,4,8)) +
  coord_cartesian(ylim = c(0,12), clip="off") +
  theme_bw() + 
  theme(panel.grid = element_blank(),
        legend.position = c(0.2,0.55),
        axis.title.y.right = element_text(face="bold"),
        axis.text.y.right = element_blank(),
        axis.ticks.y.right = element_blank(),
        plot.title = element_text(hjust=0.5),
        legend.background = element_blank())
F1B
save(F1B,file="data processed/Figure 1B - DHW Profiles.Rdata")

temp$DHW1<-NULL 
temp$DHW4<-NULL


#Load nubbin status data. File format: 5 columns-Nubbin,Tank,Colony,Date,Status. Time format: M/DD/YYYY
stres<-read.csv("data raw/Acropora long term stress experiment 2018 - Results.csv")
stres$Sampling.Date = mdy(stres$Sampling.Date)
head(stres)
#Join by date, to assign hours from 0 to measurment time points
stres<-left_join(stres,log_times)
#Seting the time of the first assesment as 0
stres$time<-stres$time-log_times$time[1]


#Converting time to DHW's, individually for each tank
stres$DHW<-rep(NA,nrow(stres))

for(i in 1:4){
  #Select tank
  x<-stres[stres$Tank==tank[i]&stres$time<=max(temp$time[!is.na(temp[,i+2])]),]
  rownames(x) = 1:nrow(x)
  
  for (j in 1:nrow(x)){
    #Assign correct DHW from the processed temperature data
    x$DHW[j]<-temp[round(temp$time,6)==round(x$time[j],6),7+i]
  }
  #Modify the original data frame
  stres[stres$Tank==tank[i]&stres$time<=max(temp$time[!is.na(temp[,i+2])]),]<-x
}


# Remove the control tank data and sort
stres<-stres[stres$Tank%in%tank,]
#Remove entries where nubbins are not healthy at time zero - remove whole nubbin
stres = stres %>%
  group_by(Nubbin) %>%
  mutate(UnhealthyNub.t0 = ifelse(Status[which.min(time)] > 0, 1, 0))
stres = stres[!stres$UnhealthyNub.t0,]
stres = stres[-which(colnames(stres)=="UnhealthyNub.t0")]
#Remove rows with no DHW assigned
stres<-stres[complete.cases(stres),]




#Because the nubbin status was assesed at different DHW for each tank, the datapoints don't align
#We need to deffine a new set of points with identical DHW for each tank
#The DHW rane will be divided into 20 parts

#Setting the range to 0-the smallest of tanks maxima
DHW_max<-max(max(temp$DHW2,na.rm=TRUE),max(temp$DHW3,na.rm=TRUE),
             max(temp$DHW5,na.rm=TRUE),max(temp$DHW6,na.rm=TRUE))
DHW_min<-min(stres$DHW)



for (i in 1:4){
  #selecting tank
  x<-stres[stres$Tank==tank[i],]
  x<-x[!is.na(x$DHW),]
  x<-x[order(x$Nubbin,x$DHW),]
  # Dividing the DHW range and making the output matrix
  y<-as.data.frame(matrix(nrow=length(x$Nubbin[!duplicated(x$Nubbin)]),ncol=24))
  # Col names are DHW's
  colnames(y)<-c("Nubbin", "Colony", "Tank",seq(from=DHW_min,to=DHW_max,by=(DHW_max-DHW_min)/20))
  y$Nubbin<-x$Nubbin[!duplicated(x$Nubbin)]
  z<-x[!duplicated(x[,c(1,2)]),]
  y$Colony<-z$Colony_ID[z$Nubbin==y$Nubbin]
  y$Tank<-rep(tank[i],nrow(y))
  # For each nubbin at a given timepoint recalculate Status at desired DHW
  for (j in 1:nrow(y)){
    for(k in 4:ncol(y)){
      #Take desired DHW
      DHW<-as.numeric(colnames(y)[k])
      #Put it in a vector with the experimental DHW's time points and arrange increasing, remove duplicates
      DHW_profile<-as.numeric(sort(c(DHW,x$DHW[!duplicated(x$DHW)])))
      DHW_profile<-DHW_profile[!duplicated(DHW_profile)]
      #determine the position of your desired DHW. To calculate the status we will use the info for flanking timepoints
      position<-which(DHW_profile==DHW)
      #If it is the last element of the vector,
      #copy the status of the last timepoint to the output matrix
      if(position==length(DHW_profile)){
        DHW<-tail(DHW_profile,5)[1:lm_impute_number]
        status1<-mean(x$Status[x$DHW==DHW[1]&x$Nubbin==y$Nubbin[j]])
        status2<-mean(x$Status[x$DHW==DHW[2]&x$Nubbin==y$Nubbin[j]])
        status3<-mean(x$Status[x$DHW==DHW[3]&x$Nubbin==y$Nubbin[j]])
        status4<-mean(x$Status[x$DHW==DHW[4]&x$Nubbin==y$Nubbin[j]])
        status5<-mean(x$Status[x$DHW==DHW[5]&x$Nubbin==y$Nubbin[j]])
        status<-c(status1,status2,status3,status4,status5)
        status<-status[1:lm_impute_number]
        #Fit linear model using DHW and corresponding status values
        params<-coef(lm(status~DHW))
        #Save the status to the output matrix
        y[j,k]<-params[2]*as.numeric(colnames(y)[k])+params[1]
      }
      #If the desired DHW is the first element of the vector, 
      #copy the status of the first timepoint to the output matrix
      if(position==1){
        if(DHW_profile[1]==0){y[j,k]<-mean(x$Status[x$DHW==DHW_profile[1]&x$Nubbin==y$Nubbin[j]])}
        else {y[j,k]<-mean(x$Status[x$DHW==DHW_profile[2]&x$Nubbin==y$Nubbin[j]])}
      }
      #if the desired DHW is neither first nor the last element of the vector,
      #Use the status corresponding to flanking values
      if(!position%in%c(1,length(DHW_profile))){
        DHW<-c(DHW_profile[position-1], DHW_profile[position+1])
        status1<-mean(x$Status[x$DHW==DHW[1]&x$Nubbin==y$Nubbin[j]])
        status2<-mean(x$Status[x$DHW==DHW[2]&x$Nubbin==y$Nubbin[j]])
        status<-c(status1,status2)
        #Fit linear model using DHW and corresponding status values for the flanking experimental time points
        #and use the coefficients to calculate status for the desired DHW
        params<-coef(lm(status~DHW))
        #Save the status to the output matrix
        y[j,k]<-params[2]*as.numeric(colnames(y)[k])+params[1]
      }
    }
  }
  if(i==1){Nubbin_profiles<-y}
  else{Nubbin_profiles<-rbind(Nubbin_profiles,y)}
}


# replace PM and dead with values of 2 for colour or 4 for no colour
# after imputing there can be status values > 4
for(i in 4:24){	
  for(j in 1:nrow(Nubbin_profiles)){	
    if(Nubbin_profiles[j,i]>4){	
      Nubbin_profiles[j,i]<-4	
    }	
  }	
}




#Plot the replicate colony status against DHW, all tanks in one plot

colonies<-Nubbin_profiles$Colony[!duplicated(Nubbin_profiles$Colony)]

dir.create("outputs/nubbin_profiles")
for(i in 1:length(colonies)){
  name<-paste("outputs/nubbin_profiles/",colonies[i],".jpg", sep="")
  jpeg(name,width=947,height=533,quality = 100)
  color<-c("blue","red","black","green","yellow","pink")
  nubbins<-Nubbin_profiles$Nubbin[Nubbin_profiles$Colony==colonies[i]]
  for (j in 1:length(nubbins)){
    if(j==1){
      x<-as.numeric(colnames(Nubbin_profiles)[4:24])
      y<-as.numeric(Nubbin_profiles[Nubbin_profiles$Nubbin==nubbins[j],4:24])
      plot(x,y,type="b", col=color[j],ylim = c(0,4), #2),
           xlab="DHW", ylab="Status")
    }
    else{
      x<-as.numeric(colnames(Nubbin_profiles)[4:24])
      y<-as.numeric(Nubbin_profiles[Nubbin_profiles$Nubbin==nubbins[j],4:24])
      lines(x,y, col=color[j])
      points(x,y, col=color[j])
    }
  }
  y<-Nubbin_profiles[Nubbin_profiles$Nubbin%in%nubbins,4:24]
  for(k in 1:ncol(y)){
    if(k==1){
      z1<-mean(y[,k])
    }
    if(k!=1){
      z1<-c(z1,mean(y[,k]))
    }
  }
  lines(x,z1,col="red",lwd=6)
  dev.off()
}

#Calculating BMI for Colonies

BMIs<-as.data.frame(matrix(ncol=(ncol(Nubbin_profiles)-2),nrow=length(colonies)))
BMIs[,1]<-colonies
colnames(BMIs)<-c("colony",colnames(Nubbin_profiles)[4:ncol(Nubbin_profiles)])
#Rounding DHW in column names
colnames(BMIs)<-c("colony",round(as.numeric(colnames(BMIs)[2:ncol(BMIs)]),digits=1))


for(i in 1:nrow(BMIs)){
  x<-Nubbin_profiles[Nubbin_profiles$Colony==BMIs$colony[i],]
  for(j in 4:ncol(x)){
    z<-nrow(x)
    y<-as.data.frame(table(x[,j]))
    y[,1]<-as.numeric(as.character(y[,1]))
    for(k in 1:nrow(y)){
      if(k==1){
        BMI<-y[1,1]*y[1,2]/z
      }
      else{
        BMI<-BMI+(y[k,1]*y[k,2]/z)
      }
    }
    BMIs[i,j-2]<-BMI/4 # /2*100 so it is from 0 -> 1
    if(z<3){
      BMIs[i,j-2]<-NA
    }
  }
}

# Converting BMI into BSI
BSIs = BMIs
BSIs[2:ncol(BMIs)] = 1 - BMIs[2:ncol(BMIs)]
#Keep rows with no missing values
BSIs<-BSIs[complete.cases(BSIs),]

#calculating mean BSIs
BSIs$mean<-rowMeans(BSIs[,2:22])
BSIs<-BSIs[order(BSIs$mean,decreasing = T),]




# Saving Data
BSIs.spread = BSIs
colnames(BSIs.spread)[c(1,ncol(BSIs.spread))] = c("Colony_ID","BSI.dhw.av")
colnmsal=colnames(BSIs.spread)
colnms = colnmsal[-c(1,ncol(BSIs.spread))]
BSIs.all.dhw = gather(BSIs.spread, "DHW","BSI.dhw",colnms)
BSI.dhw.av = BSIs.all.dhw %>%
  group_by(Colony_ID) %>%
  summarise(CriticalDHW = as.numeric(DHW[which(BSI.dhw<0.75)[1]]))
hist(BSI.dhw.av$CriticalDHW)
summary(BSI.dhw.av$CriticalDHW)
sd(BSI.dhw.av$CriticalDHW)

BSIs.spread = full_join(BSIs.spread, BSI.dhw.av)
colnmsal=colnames(BSIs.spread)
colnms = colnmsal[-c(1,(ncol(BSIs.spread)-1):ncol(BSIs.spread))]

write.csv(BSIs.spread[-which.match(colnmsal,colnms)], "data processed/BSI.av.dhw.csv", row.names = F)

colnames(BSIs.spread)[which.match(colnmsal,colnms)] = paste("BSI.dhw",colnms,sep="_") 
write.csv(BSIs.spread[-c((ncol(BSIs.spread)-1):ncol(BSIs.spread))], "data processed/BSI.all.spread.dhw.csv",row.names = F)


# Import Symbiont Data and add PCA1
SM = read.csv("data raw/ITS2 Symbiont Type 2018.csv")
colnames(SM)
SM = SM[,c(9,10:38)]
#remove empty ITS2 Type columns
SM = SM[,-(1+which(colSums(SM[-1]) == 0))]
SM$Mixed = ifelse(rowSums(!SM[-1] == 0) > 1, "Mixed", "Homogenous")
SM = gather(SM, "Symbiont.Grp","RA",colnames(SM)[-c(1,ncol(SM))])
SM = SM[-which(SM$RA == 0),]
SM = SM %>%
  group_by(Colony_ID) %>%
  mutate(Symbiont.Group = paste(Symbiont.Grp,collapse = " & ")) %>%
  group_by(Symbiont.Group) %>%
  mutate(N.in.Symbiont.Group = length(RA))
SM = SM[-which(SM$RA <0.5),-3]
colnames(SM)


BSIs.all.dhw2 = full_join(BSIs.all.dhw, SM[-3])
BSIs.all.dhw2$Symbiont.Group.dominant = sub(" & .*","",BSIs.all.dhw2$Symbiont.Group)

BSIs.all.dhw2$Symbiont.Group[is.na(BSIs.all.dhw2$Symbiont.Group)] = "No data"
BSIs.all.dhw2$N.in.Symbiont.Group[BSIs.all.dhw2$Symbiont.Group=="No data"] = length(unique(BSIs.all.dhw2$Colony_ID[BSIs.all.dhw2$Symbiont.Group=="No data"]))
unique(BSIs.all.dhw2$N.in.Symbiont.Group)
BSIs.all.dhw2$Common.Symbiont.Group = 
  ifelse(BSIs.all.dhw2$N.in.Symbiont.Group >= 5, "Common ITS2 profile (N>=5)","Rare ITS2 profiles (N<5)")
BSIs.all.dhw2$DHW = as.numeric(BSIs.all.dhw2$DHW)

F1D = 
  ggplot() + 
  geom_point(data = BSIs.all.dhw2,
             aes(x = DHW,
                 y = BSI.dhw,
                 colour = Symbiont.Group)) + 
  labs(x =expression(paste("DHW throughout exposure ("*degree*C*"-weeks)")),
       y = "BSI") +
  binomial_smooth(data = BSIs.all.dhw2,
                  aes(x = as.numeric(DHW),
                      y = BSI.dhw,
                      colour = Symbiont.Group),
                  alpha = 0.2)+
  binomial_smooth(data = BSIs.all.dhw2,
                  aes(x = as.numeric(DHW),
                      y = BSI.dhw,
                      colour = Symbiont.Group),se=F,size=1)+
  guides(colour = guide_legend(title = "Symbiont ITS2 type")) +
  scale_y_continuous(breaks = c(0,1)) +
  scale_x_continuous(breaks = c(0,4,8,12)) +
  theme_bw() + 
  theme(panel.grid = element_blank(),
        legend.text = element_text(size=7), 
        legend.key.size = unit(.3,"cm"), 
        legend.position = c(0.35,0.28), 
        legend.background = element_blank())
F1D
save(F1D,file="data processed/Figure 1D - Symbiont-BSI Curves.Rdata")

Mod1 <- glmmTMB(BSI.dhw ~ DHW * Symbiont.Group + (1|Colony_ID),
                family = binomial(link = "logit"),
                data = BSIs.all.dhw2)
summary(Mod1)
pc = emmeans(Mod1, pairwise~DHW*Symbiont.Group, type = "response")
write.csv(as.data.frame(pc$contrasts), "outputs/Table S2 - Symbiont GLMM Pairwise comparisons.csv")

FS1 = F1D + 
  facet_wrap(~Common.Symbiont.Group) +
  theme(legend.position = c(0.18,0.25))
pdf("outputs/Figure S1 - Symbiont-BSI Curves.pdf", height = 5, width = 10)
FS1
dev.off()
