#
#    Heat Tolerance and Symbiodiniaceae Community Composition Incorporation
#
# --------------------------------------------------------------------------- #
# R script to BSI progression throughout the long heat stress experiment. This
# script is also used to incorporate the Symbiodiniaceae data into the coral
# bleaching and mortality data and save relevant processed data file.
# Note: R scripts in this repository should be run from 1 to 6 to avoid errors
# 
# Written by Liam Lachs, School of Natural and Environmental Sciences, Newcastle
# University, UK, on 01/08/2022
# --------------------------------------------------------------------------- #


library(tidyr)
library(dplyr)
library(ggplot2)
library(lubridate)


# Computing Bleaching Survival Index (BSI)
# See https://doi.org/10.1016/j.marpolbul.2003.08.024
BSIfun = function(x,Status_levs){
  props = c()
  for(i in 1:length(Status_levs)){
    props[i] = length(which(x == Status_levs[i]))/length(x)
  }
  BSI = 1 - sum(props * Status_levs)/(length(Status_levs)-1)
  return(BSI)
}
binomial_smooth <- function(...) {
  geom_smooth(method = "glm", method.args = list(family = "binomial"), ...)
}

tank<-c(2,3,5,6) # these are the stress tanks, others are non-stress checking tanks

#Load nubbin status data. File format: 5 columns-Nubbin,Tank,Colony,Date,Status. Time format: M/DD/YYYY
Stres<-read.csv("data raw/Acropora long term stress experiment 2018 - Results.csv")
head(Stres)
Stres$Sampling.Date = mdy(Stres$Sampling.Date)
Stres$Year.dec =  decimal_date(Stres$Sampling.Date)

# Remove the control tank data and sort
Stres<-Stres[Stres$Tank%in%tank,]
#Remove entries where nubbins are not healthy at time zero
bad.nubs <- Stres$Nubbin[intersect(which(Stres$Sampling.Date == "2018-08-07"),which(Stres$Status>0))]
Stres <- Stres[-which(is.na(match(Stres$Nubbin,bad.nubs))==FALSE),]
# Remove colonies which have only 2 nubbins
Stres = Stres %>%
  group_by(Colony_ID, Sampling.Date) %>%
  mutate(NoNubs.Date = length(Nubbin))
Stres<-Stres[Stres$NoNubs.Date > 2,-ncol(Stres)]

head(Stres)

length(which(Stres$Status[Stres$Sampling.Date=="2018-09-12"]==4))/nrow(Stres[Stres$Sampling.Date=="2018-09-12",])
length(which(Stres$Status[Stres$Sampling.Date=="2018-09-12"]==0))/nrow(Stres[Stres$Sampling.Date=="2018-09-12",])


Status_levs = c(0,1,2,3,4)
Stres2 = Stres %>%
  group_by(Colony_ID, Sampling.Date) %>%
  summarise(BSI = BSIfun(Status,Status_levs)) %>%
  group_by(Colony_ID) %>%
  mutate(BSI.av = mean(BSI),
         time = yday(Sampling.Date)/7 - yday(min(Stres$Sampling.Date))/7)

F1C =
ggplot() + 
  geom_line(data=Stres2,
            aes(x = time,
                y = BSI,
                colour=BSI.av,
                group=Colony_ID),
            position=position_jitter(width=.1), size = 1) + 
  scale_x_continuous(breaks = 0:5) +
  scale_y_continuous(breaks = 0:1) +
  labs(x = "Time (weeks)", 
       y = "BSI") +
  scale_colour_gradientn(colours=c("firebrick1","grey80","dodgerblue1")) + 
  guides(colour = guide_colourbar(title = "Colony heat tolerance\n(average BSI)",
                                title.position="top",
                                title.hjust = 0.5,
                                title.vjust = 0,
                                barwidth = 10,
                                barheight = 1,
                                label.vjust = 1,
                                ticks.colour = "black",
                                frame.colour="black",
                                breaks = c(0,0.5,1))) +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.background = element_blank(),
        legend.position = c(0.35, 0.35),
        legend.direction = "horizontal")
F1C
save(F1C,file="data processed/Figure 1C - BSI Timecourse.Rdata")


# Import Symbiont Data and add PCA1
SM = read.csv("data raw/ITS2 Symbiont Type 2018.csv")
colnames(SM)
SM = SM[,c(9,10:38)]
#remove empty ITS2 Type columns
SM = SM[,-(1+which(colSums(SM[-1]) == 0))]
SM$Mixed = ifelse(rowSums(!SM[-1] == 0) > 1, "Mixed", "Homogenous")
SM = gather(SM, "Symbiont.Grp","RA",colnames(SM)[-c(1,ncol(SM))])
SM = SM[-which(SM$RA == 0),]
SM = SM %>%
  group_by(Colony_ID) %>%
  mutate(Symbiont.Group = paste(Symbiont.Grp,collapse = " & ")) %>%
  group_by(Symbiont.Group) %>%
  mutate(N.in.Symbiont.Group = length(RA))
SM = SM[-which(SM$RA <0.5),-c(3,4)]

Stres2 = left_join(Stres2, SM)
Stres2$Symbiont.Group.dominant = sub(" & .*","",Stres2$Symbiont.Group)


Stres2 = Stres2[-c(4,8)]
Stres2.1 = spread(Stres2[-c(4:6)],Sampling.Date,BSI)
colnames(Stres2.1)[-1] = paste0("BSI_",sub("-",".",sub("2018-","",colnames(Stres2.1)[-1])))

write.csv(Stres2.1, "data processed/BSI.all.spread.csv",row.names = F)

Stres3 = Stres2 %>%
  group_by(Colony_ID) %>%
  summarise(BSI.av = mean(BSI),
            BSI.end = BSI[Sampling.Date=="2018-09-12"])
hist(Stres3$BSI.end)
summary(Stres3$BSI.av)
length(which(Stres3$BSI.end==1))/nrow(Stres3)
length(which(Stres3$BSI.end<0.25))/nrow(Stres3)

write.csv(Stres3, "data processed/BSI.av.csv",row.names = F)
