#
#                Growth Data Calibration and Exploration
#
# --------------------------------------------------------------------------- #
# R script to import growth data from 3D photogrammetry models, conduct 
# inter-annual comparisons, correct growth metrics to annual rates, and finally
# to compute both percentage growth metrics, and size-standardised growth 
# metrics. Further analyses of growth is conducted in script 6.
# Note: R scripts in this repository should be run from 1 to 6 to avoid errors
# 
# Written by Liam Lachs, School of Natural and Environmental Sciences, Newcastle
# University, UK, on 01/08/2022
# --------------------------------------------------------------------------- #

# Processing Growth Data
# for surface area, volume and SA of live tissue only
# Growth metrics are all wanted in centimeters

library(tidyr)
library(lubridate)
library(dplyr)
library(ggplot2)
library(ggpmisc)
library(gridExtra)
library(grid)

LMpredict = function(y,x){
  p = predict(lm(y~x),data.frame(x = seq(min(x,na.rm=T),max(x,na.rm=T),length.out=100)),se=T)
  p$CIup = p$fit + 1.96*p$se.fit
  p$CIlo = p$fit - 1.96*p$se.fit
  p$x = seq(min(x,na.rm=T),max(x,na.rm=T),length.out=100)
  p = as.data.frame(p)
  return(p)
}
LMplot = function(x,y,logx=F,logy=F){
  Ax.x = sub(".*\\$","",deparse(substitute(x)))
  Ax.y = sub(".*\\$","",deparse(substitute(y)))
  dat = data.frame(x,y)
  if(logx==F & logy==T){
    dat$y=log(dat$y)
    P =
      ggplot() +
      geom_ribbon(data = LMpredict(dat$y,dat$x),
                  aes(x = x, ymin = exp(CIlo),ymax = exp(CIup)),
                  fill="grey90") +
      geom_point(data=dat,
                 aes(x = x, 
                     y = exp(y))) +
      geom_line(data = LMpredict(dat$y,dat$x),
                aes(x = x, y = exp(fit)),colour="dodgerblue",size=1) +
      labs(x = Ax.x,y = Ax.y)+
      stat_poly_eq(data=dat,
                   aes(x = x, y = y,
                       label = paste(sub("y","log(y)",..eq.label..), ..rr.label.., ..p.value.label.., sep = "~~~")),
                   formula = y~x, parse = TRUE) + theme_bw() + theme(panel.grid = element_blank())
  } 
  if(logx==T & logy==F){
    dat$x=log(dat$x)
    P =
      ggplot() +
      geom_ribbon(data = LMpredict(dat$y,dat$x),
                  aes(x = exp(x), ymin = CIlo,ymax = CIup),
                  fill="grey90") +
      geom_point(data=dat,
                 aes(x = exp(x), 
                     y = y)) +
      geom_line(data = LMpredict(dat$y,dat$x),
                aes(x = exp(x), y = fit),colour="dodgerblue",size=1) +
      labs(x = Ax.x,y = Ax.y)+
      stat_poly_eq(data=dat,
                   aes(x = x, y = y,
                       label = paste(sub("x","log(x)",..eq.label..), ..rr.label.., ..p.value.label.., sep = "~~~")),
                   formula = y~x, parse = TRUE) + theme_bw() + theme(panel.grid = element_blank())
    
  }
  if(logx==T & logy==T){
    dat$x=log(dat$x);
    dat$y=log(dat$y)
    P =
      ggplot() +
      geom_ribbon(data = LMpredict(dat$y,dat$x),
                  aes(x = exp(x), ymin = exp(CIlo),ymax = exp(CIup)),
                  fill="grey90") +
      geom_point(data=dat,
                 aes(x = exp(x), 
                     y = exp(y))) +
      geom_line(data = LMpredict(dat$y,dat$x),
                aes(x = exp(x), y = exp(fit)),colour="dodgerblue",size=1) +
      labs(x = Ax.x,y = Ax.y)+
      stat_poly_eq(data=dat,
                   aes(x = x, y = y,
                       label = paste(sub("y","log(y)",sub("x","log(x)",..eq.label..)), ..rr.label.., ..p.value.label.., sep = "~~~")),
                   formula = y~x, parse = TRUE) + theme_bw() + theme(panel.grid = element_blank())
  }
  if(logx==F & logy==F){
    P =
      ggplot() +
      geom_ribbon(data = LMpredict(dat$y,dat$x),
                  aes(x = x, ymin = CIlo,ymax = CIup),
                  fill="grey90") +
      geom_point(data=dat,
                 aes(x = x, 
                     y = y)) +
      geom_line(data = LMpredict(dat$y,dat$x),
                aes(x = x, y = fit),colour="dodgerblue",size=1) +
      labs(x = Ax.x,y = Ax.y)+
      stat_poly_eq(data=dat,
                   aes(x = x, y = y,
                       label = paste(..eq.label.., ..rr.label.., ..p.value.label.., sep = "~~~")),
                   formula = y~x, parse = TRUE) + theme_bw() + theme(panel.grid = element_blank())
  }
  return(P)
}
MyStd = function(x,pop) { (x - mean(pop, na.rm = TRUE)) / sd(pop, na.rm = TRUE)}
blu = colorRampPalette(c("black","dodgerblue1","white")); blu = blu(100)
red = colorRampPalette(c("black","firebrick1","white")); red = red(100)

# Do you want to standardise Growth metrics for methods comparison (SAlive)? logical
std.method.compare = F

Grow = read.csv("data raw/3D Colony Sizes SA-VOL-SAlive.csv")
colnames(Grow)
Grow$Colony_ID = as.factor(Grow$Colony_ID)
Grow$Date = ymd(sub("\\.","-",as.character(sapply(strsplit(Grow$Model, "_"), function(x) x[3]))))

levels(as.factor(Grow$Date))
length(levels(Grow$Colony_ID))
levels(Grow$Colony_ID)


# Convert metres to centimetres
Grow$SA.pre.base.fill = Grow$SA.pre.base.fill*100*100
Grow$Volume = Grow$Volume*100*100*100
Grow$SA.Live = Grow$SA.Live*100*100

Grow2 = Grow %>%
  complete(Year, nesting(Colony_ID)) %>%
  group_by(Colony_ID) %>%
  summarise(SAlive.17 = SA.Live[which(Year == 2017)], SAlive.18 = SA.Live[which(Year == 2018)], SAlive.19 = SA.Live[which(Year == 2019)],
            Volume.17 = Volume[which(Year == 2017)], Volume.18 = Volume[which(Year == 2018)], Volume.19 = Volume[which(Year == 2019)],
            SA.17 = SA.pre.base.fill[which(Year == 2017)], SA.18 = SA.pre.base.fill[which(Year == 2018)], SA.19 = SA.pre.base.fill[which(Year == 2019)],
            Grow.SAlive.17.18 = SA.Live[which(Year == 2018)] - SA.Live[which(Year == 2017)],
            Grow.SAlive.18.19 = SA.Live[which(Year == 2019)] - SA.Live[which(Year == 2018)],
            Grow.Volume.17.18 = Volume[which(Year == 2018)] - Volume[which(Year == 2017)],
            Grow.Volume.18.19 = Volume[which(Year == 2019)] - Volume[which(Year == 2018)],
            Grow.SA.17.18 = SA.pre.base.fill[which(Year == 2018)] - SA.pre.base.fill[which(Year == 2017)],
            Grow.SA.18.19 = SA.pre.base.fill[which(Year == 2019)] - SA.pre.base.fill[which(Year == 2018)],
            NumDays.17.18 = interval(Date[which(Year == 2017)], Date[which(Year == 2018)]) %/% days(1),
            NumDays.18.19 = interval(Date[which(Year == 2018)], Date[which(Year == 2019)]) %/% days(1))

# Initial Size
Grow2$SAlive.initial = ifelse(is.na(Grow2$SAlive.17),Grow2$SAlive.18,Grow2$SAlive.17) 
Grow2$Vol.initial = ifelse(is.na(Grow2$Volume.17),Grow2$Volume.18,Grow2$Volume.17) 
Grow2$SA.initial = ifelse(is.na(Grow2$SA.17),Grow2$SA.18,Grow2$SA.17)

Diam = read.csv("data raw/Colony Diameters.csv") 
Diam$Colony_ID = as.factor(as.character(Diam$Colony_ID))
Grow2 = left_join(Grow2,Diam)

# Calibrate initial Max Diameter from initial SA.live
FS4 =
  LMplot(logx = T, x = Grow2$SA.initial,
         logy = T, y = Grow2$Initial_Diameter)
FS4 = FS4 + labs(x = bquote(Initial~surface~area~(cm^2)),
                   y = bquote(Initial~max~diameter~(cm)))
pdf("outputs/Figure S5 - Initial Diameter Estimation Curve.pdf",height=4, width=6)
FS4
dev.off()

Init.Diam.Estimator = function(SA.initial){
  dat = data.frame(x=log(Grow2$SA.initial),
                   y=log(Grow2$Initial_Diameter))
  mod = lm(y~x,data=dat)
  fit = predict(mod,newdata=data.frame(x=log(SA.initial)))
  fit=exp(fit)
  return(fit)
}
Grow2$Initial_Diameter.est = Init.Diam.Estimator(Grow2$SA.initial)
Grow2$Initial_Diameter.est17 = Init.Diam.Estimator(Grow2$SA.17)
Grow2$Initial_Diameter.est18 = Init.Diam.Estimator(Grow2$SA.18)
#replace NA values for Initial Diameter, with estimated values based on SAlive.initial
Grow2$Initial_Diameter.est.NA = Grow2$Initial_Diameter
Grow2$Initial_Diameter.est.NA[is.na(Grow2$Initial_Diameter)] = Grow2$Initial_Diameter.est[is.na(Grow2$Initial_Diameter)]

# Note mismatch between the circular equivalent diameter (based on SA.initial) and the measured Initial diameter 
plot(2*sqrt(Grow2$SA.initial/pi),
     Grow2$Initial_Diameter.est.NA)




# ---------------------------------------------------- #
#         Method 1 - raw SAlive growth (cm2/ year)     #
# ---------------------------------------------------- #
# Compute annual growth per year
Grow2$Grow.SAlive.17.18.pyr   = (Grow2$Grow.SAlive.17.18 / Grow2$NumDays.17.18) * 365
Grow2$Grow.SAlive.18.19.pyr   = (Grow2$Grow.SAlive.18.19 / Grow2$NumDays.18.19) * 365
Grow2$Grow.Volume.17.18.pyr   = (Grow2$Grow.Volume.17.18 / Grow2$NumDays.17.18) * 365
Grow2$Grow.Volume.18.19.pyr   = (Grow2$Grow.Volume.18.19 / Grow2$NumDays.18.19) * 365
Grow2$Grow.SA.17.18.pyr       = (  Grow2$Grow.SA.17.18   / Grow2$NumDays.17.18) * 365
Grow2$Grow.SA.18.19.pyr       = (  Grow2$Grow.SA.18.19   / Grow2$NumDays.18.19) * 365

# ---------------------------------------------------- #
#         Method 2 - percentage SAlive growth (%)      #
# ---------------------------------------------------- #
# Convert Annual growth (per year) to percentage of initial size
Grow2$Grow.SAlive.17.18.pyr.perc = 100*(Grow2$Grow.SAlive.17.18.pyr / Grow2$SAlive.17)
Grow2$Grow.SAlive.18.19.pyr.perc = 100*(Grow2$Grow.SAlive.18.19.pyr / Grow2$SAlive.18)

# ---------------------------------------------------------------------- #
#         Method 3 - Diameter-standardised SAlive growth (cm/ year)     #
# ---------------------------------------------------------------------- #
# Standardise Area Growth (cm^2) by colony max diameter (cm) (per year)
Grow2$Grow.SAlive.17.18.pyr.Dstd = Grow2$Grow.SAlive.17.18.pyr * (mean(Grow2$Initial_Diameter.est17,na.rm=T)/ Grow2$Initial_Diameter.est17)
Grow2$Grow.SAlive.18.19.pyr.Dstd = Grow2$Grow.SAlive.18.19.pyr * (mean(Grow2$Initial_Diameter.est18,na.rm=T) / Grow2$Initial_Diameter.est18)





# Compute annual growth across whole study (per year if whole study not possible)
Grow2$Grow.SAlive = (rowSums(cbind(Grow2$Grow.SAlive.17.18,Grow2$Grow.SAlive.18.19),na.rm=T) / rowSums(cbind(Grow2$NumDays.17.18,Grow2$NumDays.18.19),na.rm=T)) * 365
Grow2$Grow.Vol  = (rowSums(cbind(Grow2$Grow.Volume.17.18,Grow2$Grow.Volume.18.19),na.rm=T) / rowSums(cbind(Grow2$NumDays.17.18,Grow2$NumDays.18.19),na.rm=T)) * 365
Grow2$Grow.SA       = (rowSums(cbind(Grow2$Grow.SA.17.18,Grow2$Grow.SA.18.19),na.rm=T) / rowSums(cbind(Grow2$NumDays.17.18,Grow2$NumDays.18.19),na.rm=T)) * 365

# Convert Annual growth (whole period) to percentage of initial size
Grow2$Grow.SAlive.perc = Grow2$Grow.SAlive / Grow2$SAlive.initial
Grow2$Grow.SA.perc = Grow2$Grow.SA / Grow2$SA.initial
Grow2$Grow.Vol.perc = Grow2$Grow.Vol / Grow2$Vol.initial

# Standardise Area Growth (cm^2) to colony max diameter (cm)
# Standard diameter = population mean of all initial diameters
# Volumetric adjustment factor =  (Standard area )/(Initial diameter * Initial height)
# Standard area = population mean of all areas (initial diameters * population mean of all initial heights)
# Assume Initial Height = half Initial Diameter
Grow2$Grow.SAlive.Dstd = Grow2$Grow.SAlive * (mean(Grow2$Initial_Diameter.est.NA) / Grow2$Initial_Diameter.est.NA)
Grow2$Grow.SA.Dstd     = Grow2$Grow.SA     * (mean(Grow2$Initial_Diameter.est.NA) / Grow2$Initial_Diameter.est.NA)
Grow2$Grow.Vol.Dstd = Grow2$Grow.Vol * (mean(Grow2$Initial_Diameter.est.NA*(Grow2$Initial_Diameter.est.NA/2)) / (Grow2$Initial_Diameter.est.NA * (Grow2$Initial_Diameter.est.NA/2)))


write.csv(Grow2,"data processed/Annual Growth SA-VOL-SAlive.csv", row.names = F)
