#
#                Data collation and Symbiont analyses
#
# --------------------------------------------------------------------------- #
# R script to import all heat tolerance, growth, fecundity, and Symbiodiniaceae 
# data into a single data frame. This dataset is then saved, and also used to 
# conduct initial analyses of Synbiont community composition vs. heat tolerance
# Note: R scripts in this repository should be run from 1 to 6 to avoid errors
# 
# Written by Liam Lachs, School of Natural and Environmental Sciences, Newcastle
# University, UK, on 01/08/2022
# --------------------------------------------------------------------------- #


# Collating Data for Structural Equation Modelling
library(dplyr)
library(vegan)


BSI = read.csv("data processed/BSI.av.csv")
BSI.all = read.csv("data processed/BSI.all.spread.csv")
BSI = full_join(BSI, BSI.all, "Colony_ID")

BSI.dhw = read.csv("data processed/BSI.av.dhw.csv")
BSI.all.dhw = read.csv("data processed/BSI.all.spread.dhw.csv")
BSI.dhw = full_join(BSI.dhw, BSI.all.dhw, "Colony_ID")

BSI = full_join(BSI, BSI.dhw, "Colony_ID")
plot(BSI$BSI.av, BSI$BSI.dhw.av)

Fec = read.csv("data processed/Fecundity by colony and year.csv")
Fec$Eggs.bin = ifelse(Fec$Eggs.av > 0,1,0)
DB = full_join(BSI, Fec, "Colony_ID")
colnames(DB)


DB$BSI.av.rank = NA
DB$BSI.av.rank[!is.na(DB$BSI.av)] = DB$BSI.av[!is.na(DB$BSI.av)][order(DB$BSI.av[!is.na(DB$BSI.av)], decreasing = TRUE)]
DB$RHT = "Medium"
DB$RHT[DB$BSI.av >= 0.8] = "High"
DB$RHT[DB$BSI.av <  0.7] = "Low"
DB$RHT[is.na(DB$BSI.av)] = "Unknown"

# Add Growth Data
Grow = read.csv("data processed/Annual Growth SA-VOL-SAlive.csv")
colnames(Grow)
DB = full_join(DB, Grow, "Colony_ID")
# compute growth for Egg years 
DB$Grow.SA.EggYear = NA
DB$Grow.Vol.EggYear = NA
DB$Grow.SAlive.EggYear = NA
DB$Grow.SA.EggYear[which(DB$Year.EggNum == "2018")]      = DB$Grow.SA.17.18.pyr[which(DB$Year.EggNum == "2018")]
DB$Grow.SA.EggYear[which(DB$Year.EggNum == "2019")]      = DB$Grow.SA.18.19.pyr[which(DB$Year.EggNum == "2019")]
DB$Grow.SA.EggYear[which(DB$Year.EggNum == "2018_2019")] = DB$Grow.SA          [which(DB$Year.EggNum == "2018_2019")]
DB$Grow.Vol.EggYear[which(DB$Year.EggNum == "2018")]      = DB$Grow.Volume.17.18.pyr[which(DB$Year.EggNum == "2018")]
DB$Grow.Vol.EggYear[which(DB$Year.EggNum == "2019")]      = DB$Grow.Volume.18.19.pyr[which(DB$Year.EggNum == "2019")]
DB$Grow.Vol.EggYear[which(DB$Year.EggNum == "2018_2019")] = DB$Grow.Vol             [which(DB$Year.EggNum == "2018_2019")]
DB$Grow.SAlive.EggYear[which(DB$Year.EggNum == "2018")]      = DB$Grow.SAlive.17.18.pyr[which(DB$Year.EggNum == "2018")]
DB$Grow.SAlive.EggYear[which(DB$Year.EggNum == "2019")]      = DB$Grow.SAlive.18.19.pyr[which(DB$Year.EggNum == "2019")]
DB$Grow.SAlive.EggYear[which(DB$Year.EggNum == "2018_2019")] = DB$Grow.SAlive          [which(DB$Year.EggNum == "2018_2019")]

PM2 = readxl::read_excel("data raw/Endpoint Mortality.xlsx",sheet=1)
DB = full_join(DB, PM2, "Colony_ID")


# COlony Fecundity
pd = read.csv("data raw/Polyp Density.csv")
pd.av = pd %>%
  group_by(Colony_ID) %>%
  summarise(Polyp_Density.av = mean(Polyp_Density))

DB$Polyp_Density.av.est = DB$Polyp_Density.av
DB$Polyp_Density.av.est[is.na(DB$Polyp_Density.av.est)] =
  mean(pd.av$Polyp_Density.av, na.rm = T)
DB$Eggs.per.colony = NA
ind = which(DB$Year.EggNum=="2018")
DB$Eggs.per.colony[ind] = DB$Eggs.av[ind] * DB$Polyp_Density.av.est[ind] * DB$SAlive.18[ind]
ind = which(DB$Year.EggNum=="2019")
DB$Eggs.per.colony[ind] = DB$Eggs.av[ind] * DB$Polyp_Density.av.est[ind] * DB$SAlive.19[ind]
DB$Egg.Vol.per.colony = DB$Eggs.per.colony*DB$Egg.Vol/(10^3) # to put in cm3 from mm3
hist(DB$Egg.Vol.per.colony)


# Import Symbiont Data and add PCA1
SM = read.csv("data raw/ITS2 Symbiont Type 2018.csv")
colnames(SM)
SM = SM[,c(9,10:38)]
#remove empty ITS2 Type columns
SM = SM[,-(1+which(colSums(SM[-1]) == 0))]

#Proportions of major clades
grps = colnames(SM); Ngrps = length(grps)
Props = data.frame(SM[1])
Props$C40.C3.C115.C40h = SM$C40.C3.C115.C40h/rowSums(SM[-1])
Props$C40 = rowSums(SM[which(grepl("C4",substr(grps,1,2)))])/rowSums(SM[-1])
Props$C15 = rowSums(SM[which(grepl("C1",substr(grps,1,2)))])/rowSums(SM[-1])
Props$D1 = rowSums(SM[which(grepl("D1",substr(grps,1,2)))])/rowSums(SM[-1])


Rel.Abund = SM[-1]
Rel.Abund = Rel.Abund/rowSums(Rel.Abund)
PCA <- rda(Rel.Abund ~ 1, scale=FALSE)
pca.sum = summary(PCA); pca.sum
PCAsym = data.frame(Colony_ID = SM$Colony_ID)
PCAsym$PC1 = PCA$CA$u[,1]
PCAsym$PC2 = PCA$CA$u[,2]



DB = left_join(DB, PCAsym, "Colony_ID")
DB = left_join(DB, Props, "Colony_ID")
colnames(DB)

SM.RHT = left_join(SM,DB[!is.na(match(colnames(DB),c("Colony_ID","BSI.av","RHT")))])
SM.RHT$RHT[is.na(SM.RHT$RHT)]="Unknown"
unique(SM.RHT$RHT)


pdf("outputs/Figure S2 - Symbionts PCA.pdf",width =6,height = 6)

cols <- recode(SM.RHT$RHT, High = "dodgerblue", Low = "firebrick", Medium = "goldenrod2",  Unknown = "Black")

# EmptyPlot
plot(PCA, scaling = 0, type = "n",
     xlab=paste("PC1 (",
                100*round(pca.sum$cont$importance["Proportion Explained","PC1"],3),
                "%)", sep = ""),
     ylab=paste("PC2 (",
                100*round(pca.sum$cont$importance["Proportion Explained","PC2"],3),
                "%)", sep = ""), 
     xlim = c(-0.5,0.5), ylim = c(-0.5,0.5))

# # Ellipse
ordiellipse(PCA, display = "sites", conf = 0.95, kind = "sd", scaling = 0,
            groups = SM.RHT$RHT, draw = "polygon",
            col =  c("dodgerblue","firebrick","goldenrod2", "black"), #"grey92",
            alpha = 0.07,
            border = c("dodgerblue","firebrick","goldenrod2", "black"))#"grey80")

# Text & Points
points(
       x = as.vector(PCA$CA$u[,1]) +runif(n=nrow(Rel.Abund),min=-0.01,max = 0.01),
       y = as.vector(PCA$CA$u[,2])+runif(n=nrow(Rel.Abund),min=-0.01,max = 0.01),
       cex = 1.2,
       bg= NA,
       col = as.character(cols),
       pch = 21)

legend("topleft", 
       title = "Heat tolerance",
       fill = c("black","dodgerblue","goldenrod2","firebrick"), 
       legend = c("Unknown","High" , "Medium", "Low"),
       cex=1, bty="n")

# Draw arrows for Family Group Types
(fit <- envfit(PCA, Rel.Abund, perm = 999))
plot(fit, add = TRUE, col = "grey40", cex = 0.7,
     labels = colnames(Rel.Abund))

dev.off()






write.csv(DB,"data processed/Full_dataset.csv",row.names = F)

