#
#                              Full Data analysis
#
# --------------------------------------------------------------------------- #
# R script to import the full trait dataset and then conduct analyses on:
# A) Trait Exploration
# B) Growth vs. Size
# C) Partial Mortality
# D) Heat tolerance (average BSI) vs traits
# E) Progression of the relationship: Instantaneous BSI vs trait
# Note: R scripts in this repository should be run from 1 to 6 to avoid errors
# 
# Written by Liam Lachs, School of Natural and Environmental Sciences, Newcastle
# University, UK, on 01/08/2022
# --------------------------------------------------------------------------- #


library(reshape2)
library(ggplot2)
library(gridExtra)
library(grid)
library(ggpmisc)
library(merTools)
library(tidyr)
library(dplyr)
library(lubridate)
library(MuMIn)
library(sf)
library(INLA)
library(cowplot)
library(ggpubr)

setwd("C:/Users/liaml/OneDrive - Newcastle University/Coral Assist PhD/Trait Trade-offs/Repository - Coral trait trade-offs/Analysis")

# set the DHW and day levels for BMIs
HTdhws = c(0.0,0.5,1.1,1.6,2.2,2.7,3.2,3.8,4.3,4.8,5.4,5.9,6.5,7.0,7.5,8.1,8.6,9.2,9.7,10.2,10.8)
HTdays = c(0,  6, 11, 15, 20, 23, 25 ,27:33, 35, 36)



# ---------------------------------------------------- #
#          Useful Functions for Analysis               #
# ---------------------------------------------------- #
binomial_smooth <- function(...) {
  geom_smooth(method = "glm", method.args = list(family = "binomial"), ...)
}
MyStd = function(x) { (x - mean(x, na.rm = TRUE)) / sd(x, na.rm = TRUE)}
MyStdReverse = function(xstd,xpop){(xstd * sd(xpop, na.rm = TRUE)) + mean(xpop, na.rm = TRUE)}
which.match = function(x,y){
  which(is.na(match(x,y))==FALSE)
}
LMpredict = function(y,x){
  p = predict(lm(y~x),data.frame(x = seq(min(x,na.rm=T),max(x,na.rm=T),length.out=100)),se=T)
  p$CIup = p$fit + 1.96*p$se.fit
  p$CIlo = p$fit - 1.96*p$se.fit
  p$x = seq(min(x,na.rm=T),max(x,na.rm=T),length.out=100)
  p = as.data.frame(p)
  return(p)
}
LMplot = function(x,y,logx=F,logy=F, returnMod = F){
  Ax.x = sub(".*\\$","",deparse(substitute(x)))
  Ax.y = sub(".*\\$","",deparse(substitute(y)))
  dat = data.frame(x,y)
  if(logx==F & logy==T){
    dat$y=log(dat$y)
    mod = lm(y~x,data=dat)
    P =
      ggplot() +
      geom_ribbon(data = LMpredict(dat$y,dat$x),
                  aes(x = x, ymin = exp(CIlo),ymax = exp(CIup)),
                  fill="grey90") +
      geom_point(data=dat,
                 aes(x = x, 
                     y = exp(y))) +
      geom_line(data = LMpredict(dat$y,dat$x),
                aes(x = x, y = exp(fit)),colour="dodgerblue",size=1) +
      labs(x = Ax.x,y = Ax.y)+
      stat_poly_eq(data=dat,
                   aes(x = x, y = y,
                       label = paste(sub("y","log(y)",..eq.label..), ..rr.label.., ..p.value.label.., sep = "~~~")),
                   formula = y~x, parse = TRUE) + theme_bw() + theme(panel.grid = element_blank())
  } 
  if(logx==T & logy==F){
    dat$x=log(dat$x)
    mod = lm(y~x,data=dat)
    P =
      ggplot() +
      geom_ribbon(data = LMpredict(dat$y,dat$x),
                  aes(x = exp(x), ymin = CIlo,ymax = CIup),
                  fill="grey90") +
      geom_point(data=dat,
                 aes(x = exp(x), 
                     y = y)) +
      geom_line(data = LMpredict(dat$y,dat$x),
                aes(x = exp(x), y = fit),colour="dodgerblue",size=1) +
      labs(x = Ax.x,y = Ax.y)+
      stat_poly_eq(data=dat,
                   aes(x = x, y = y,
                       label = paste(sub("x","log(x)",..eq.label..), ..rr.label.., ..p.value.label.., sep = "~~~")),
                   formula = y~x, parse = TRUE) + theme_bw() + theme(panel.grid = element_blank())
    
  }
  if(logx==T & logy==T){
    dat$x=log(dat$x);
    dat$y=log(dat$y)
    mod = lm(y~x,data=dat)
    P =
      ggplot() +
      geom_ribbon(data = LMpredict(dat$y,dat$x),
                  aes(x = exp(x), ymin = exp(CIlo),ymax = exp(CIup)),
                  fill="grey90") +
      geom_point(data=dat,
                 aes(x = exp(x), 
                     y = exp(y))) +
      geom_line(data = LMpredict(dat$y,dat$x),
                aes(x = exp(x), y = exp(fit)),colour="dodgerblue",size=1) +
      labs(x = Ax.x,y = Ax.y)+
      stat_poly_eq(data=dat,
                   aes(x = x, y = y,
                       label = paste(sub("y","log(y)",sub("x","log(x)",..eq.label..)), ..rr.label.., ..p.value.label.., sep = "~~~")),
                   formula = y~x, parse = TRUE) + theme_bw() + theme(panel.grid = element_blank())
  }
  if(logx==F & logy==F){
    mod = lm(y~x,data=dat)
    P =
      ggplot() +
      geom_ribbon(data = LMpredict(dat$y,dat$x),
                  aes(x = x, ymin = CIlo,ymax = CIup),
                  fill="grey90") +
      geom_point(data=dat,
                 aes(x = x, 
                     y = y)) +
      geom_line(data = LMpredict(dat$y,dat$x),
                aes(x = x, y = fit),colour="dodgerblue",size=1) +
      labs(x = Ax.x,y = Ax.y)+
      stat_poly_eq(data=dat,
                   aes(x = x, y = y,
                       label = paste(..eq.label.., ..rr.label.., ..p.value.label.., sep = "~~~")),
                   formula = y~x, parse = TRUE) + theme_bw() + theme(panel.grid = element_blank())
  }
  if(returnMod == F){
    return(P)
  }
  if(returnMod == T){
    return(mod)
  }
}
LMplotINLA = function(x,y,returnMod = F){
  Ax.x = sub(".*\\$","",deparse(substitute(x)))
  Ax.y = sub(".*\\$","",deparse(substitute(y)))
  dat = data.frame(x,y)
  dat = na.omit(dat)
  # Bayesian
  MyData <- data.frame(x = seq(from = min(dat$x), 
                               to   = max(dat$x),
                               length = 50))
  Xp <- model.matrix(~  x, data = MyData)
  Xp <- as.data.frame(Xp)   # remove character rubbish
  head(Xp)
  lc1 <- inla.make.lincombs(Xp)
  I.Pred <- inla(y ~ x,
                 family="gaussian",
                 control.predictor = list(compute = TRUE, link = 1), 
                 quantiles = c(0.025, 0.125, 0.25, 0.75, 0.875, 0.975),             
                 lincomb = lc1,                            
                 data = dat)
  MyData2 <- cbind(MyData, 
                   I.Pred$summary.lincomb.derived[, c("mean", 
                                                      "0.025quant", 
                                                      # "0.125quant",
                                                      # "0.25quant",
                                                      # "0.75quant",
                                                      # "0.875quant",
                                                      "0.975quant")])
  head(MyData2)
  colnames(MyData2)[-1] <- c("mean" = "mu", 
                             "0.025quant" = "selo.q95", 
                             # "0.125quant" = "selo.q75", 
                             # "0.25quant" = "selo.q50", 
                             # "0.75quant" = "seup.q50", 
                             # "0.875quant" = "seup.q75", 
                             "0.975quant" = "seup.q95")
  head(MyData2)
  
  
  INLAEQ = function(x){as.numeric(ifelse(abs(x)<=0.005,format(x,digits=2),round(x,2)))}
  
  b0av = INLAEQ(I.Pred$summary.fixed["(Intercept)","mean"])
  b0lo = INLAEQ(I.Pred$summary.fixed["(Intercept)","0.025quant"])
  b0up = INLAEQ(I.Pred$summary.fixed["(Intercept)","0.975quant"])
  
  b1av = INLAEQ(I.Pred$summary.fixed["x","mean"])
  b1lo = INLAEQ(I.Pred$summary.fixed["x","0.025quant"])
  b1up = INLAEQ(I.Pred$summary.fixed["x","0.975quant"])
  
  
  P =
    ggplot() + 
    geom_ribbon(data = MyData2,
                aes(x = x, 
                    ymax = seup.q95, 
                    ymin = selo.q95),
                fill="grey90") +
    geom_point(data=dat,
               aes(x = x, 
                   y = y)) +
    geom_line(data = MyData2,
              aes(x = x , y = mu),
              colour="dodgerblue",size=1) +
    labs(x = Ax.x,y = Ax.y)+ 
    annotation_custom(grid::textGrob(x = unit(0.05, "npc"), y = unit(0.25, "npc"),label = bquote(beta[0]==.(b0av)~"["*.(b0lo)*","~.(b0up)*"]"), hjust=0)) +
    annotation_custom(grid::textGrob(x = unit(0.05, "npc"), y = unit(0.15, "npc"),label = bquote(beta[1]==.(b1av)~"["*.(b1lo)*","~.(b1up)*"]"), hjust=0)) +
    theme_bw() + theme(panel.grid = element_blank())
  P
  if(returnMod == F){
    return(P)
  }
  if(returnMod == T){
    return(I.Pred)
  }
}
BetaplotINLA = function(x,y,returnMod = F){
  Ax.x = sub(".*\\$","",deparse(substitute(x)))
  Ax.y = sub(".*\\$","",deparse(substitute(y)))
  dat = data.frame(x,y)
  dat = na.omit(dat)
  
  # Beta Transformation
  N <- nrow(dat)
  dat$y <- (dat$y*(N-1) + 0.5) / N
  
  # For Predictions add as NA
  dat = rbind(dat, data.frame(y=rep(NA,50), x = seq(from = min(dat$x), 
                                                    to   = max(dat$x),
                                                    length = 50)))
  # Bayesian
  I.Pred <- inla(y ~ x,
                 family="beta",
                 control.predictor = list(compute = TRUE, link=1), 
                 quantiles = c(0.025, 0.125, 0.25, 0.75, 0.875, 0.975),    
                 
                 data = dat)
  MyData2 <- cbind(MyData, 
                   I.Pred$summary.fitted.values[(N+1):nrow(dat), c("mean", "0.025quant","0.975quant")])
  colnames(MyData2)[-1] <- c("mean" = "mu", "0.025quant" = "selo.q95", "0.975quant" = "seup.q95")
  head(MyData2)
  
  
  INLAEQ = function(x){as.numeric(ifelse(abs(x)<=0.005,format(x,digits=2),round(x,2)))}
  
  b0av = INLAEQ(I.Pred$summary.fixed["(Intercept)","mean"])
  b0lo = INLAEQ(I.Pred$summary.fixed["(Intercept)","0.025quant"])
  b0up = INLAEQ(I.Pred$summary.fixed["(Intercept)","0.975quant"])
  
  b1av = INLAEQ(I.Pred$summary.fixed["x","mean"])
  b1lo = INLAEQ(I.Pred$summary.fixed["x","0.025quant"])
  b1up = INLAEQ(I.Pred$summary.fixed["x","0.975quant"])
  
  
  P =
    ggplot() + 
    geom_ribbon(data = MyData2,
                aes(x = x, 
                    ymax = seup.q95, 
                    ymin = selo.q95),
                fill="grey90") +
    geom_point(data=dat,
               aes(x = x, 
                   y = y)) +
    geom_line(data = MyData2,
              aes(x = x , y = mu),
              colour="dodgerblue",size=1) +
    labs(x = Ax.x,y = Ax.y)+ 
    annotation_custom(grid::textGrob(x = unit(0.05, "npc"), y = unit(0.95, "npc"),label = bquote(beta[0]==.(b0av)~"["*.(b0lo)*","~.(b0up)*"]"), hjust=0)) +
    annotation_custom(grid::textGrob(x = unit(0.05, "npc"), y = unit(0.85, "npc"),label = bquote(beta[1]==.(b1av)~"["*.(b1lo)*","~.(b1up)*"]"), hjust=0)) +
    theme_bw() + theme(panel.grid = element_blank())
  P
  if(returnMod == F){
    return(P)
  }
  if(returnMod == T){
    return(I.Pred)
  }
}
LMplotBinom = function(x,y,logx=F, returnMod=F){
  dat = data.frame(x,y)
  Ax.x = sub(".*\\$","",deparse(substitute(x)))
  Ax.y = sub(".*\\$","",deparse(substitute(y)))
  mod = glm(y~x,data=dat,family = "binomial")
  modsum=summary(mod)
  R2 = round(1 - (modsum$deviance / modsum$null.deviance),2)
  Pv = round(modsum$coefficients["x","Pr(>|z|)"],3)
  Stats=bquote(R^2==.(R2)~P==.(Pv))
  P =
    ggplot(data=dat,
           aes(x,y)) +
      geom_point() + binomial_smooth(formula=y~x) + 
      annotate(geom="text", x = quantile(x,probs=0.02,na.rm=T),y=0.9,
                label=Stats) +
    labs(x = Ax.x,y = Ax.y)+
      theme_bw() + theme(panel.grid = element_blank()) + lims(y=c(0,1))
  if(returnMod == F){
    return(P)
  }
  if(returnMod == T){
    return(mod)
  }
}
BSIquartilesPlot = function(x,logx=F,method="lm", BSI.bin = F, returnMod=F){ # or method="glm" for binomial plot
  Ax.x = sub(".*\\$","",deparse(substitute(x)))
  Plist=list()
  Modlist = list()
  for(q in 1:9){
    Quart = paste0("BSI.q",q,"0")
    BSI = TO[,which(colnames(TO) == Quart)]
    if(BSI.bin == T){
      BSI = ifelse(BSI >= 0.5,1,0)
    }
    if(method=="lm"){
      Plist[[q]] = 
        LMplot(logx = logx, x = x,
               logy = F, y = BSI) + labs(y = Quart,x=Ax.x) + lims(y=c(0,1))
      Modlist[[q]] = 
        LMplot(logx = logx, x = x,
               logy = F, y = BSI, returnMod = T)
      
    }
    if(method=="glm"){
      Plist[[q]] =
        LMplotBinom(x = x, logx=logx,
                    y = BSI) + labs(y = Quart,x=Ax.x)
      Modlist[[q]] =
        LMplotBinom(x = x, logx=logx,
                    y = BSI, returnMod = T)
    }
  }
  if(returnMod == F){
    return(grid.arrange(grobs=Plist,
                        layout_matrix = matrix(1:9,nrow=3,byrow = T)))
  }
  if(returnMod == T){
    return(ModList)
  }
}
BSItimepointPlot = function(x,logx=F,method="lm", BSI.bin = F, returnMod=F, DHW.basedBSI = F){ # or method="glm" for binomial plot
  Ax.x = sub(".*\\$","",deparse(substitute(x)))
  Plist=list()
  ModList = list()
  if(DHW.basedBSI == FALSE){
    Nmods=16
  } else {
    Nmods=21
  }
    
  for(i in 1:Nmods){
    if(DHW.basedBSI == FALSE){
      Cols = c(paste0("BSI_08.",c("07","13","18","22","27","30")),
               paste0("BSI_09.",c("01","03","04","05","06","07","08","09","11","12")))
      BSI = TO[,which(colnames(TO) == Cols[i])]
    }
    if(DHW.basedBSI == TRUE){
      Cols = paste0("BSI.dhw_",c(0.0,0.5,1.1,1.6,2.2,2.7,3.2,3.8,4.3,4.8,5.4,5.9,6.5,7.0,7.5,8.1,8.6,9.2,9.7,10.2,10.8))
      BSI = TO[,which(colnames(TO) == Cols[i])]
    }

    if(BSI.bin == T){
      BSI = ifelse(BSI >= 0.5,1,0)
    }
    if(method=="lm"){
      Plist[[i]] = 
        LMplot(logx = logx, x = x,
               logy = F, y = BSI) + labs(y = Cols[i],x=Ax.x) + lims(y=c(0,1))
      ModList[[i]] = 
        LMplot(logx = logx, x = x,
               logy = F, y = BSI, returnMod = T)
    }
    if(method=="glm"){
      Plist[[i]] =
        LMplotBinom(x = x, logx=logx,
                    y = BSI) + labs(y = Cols[i],x=Ax.x)
      ModList[[i]] = 
        LMplotBinom(x = x, logx = logx, 
                    y = BSI, returnMod = T)
    }
  }
  if(returnMod == F){
    n = Nmods
    nr = 4
    nc = ceiling(n / 4)
    tot=nc*nr
    figs = c(1:n,rep(NA,tot-n))
    return(grid.arrange(grobs=Plist,
                        layout_matrix = matrix(figs,nrow=4,byrow = T)))
  }
  if(returnMod == T){
    return(ModList)
  }
}
BSISlopePlot = function(ModList,Predictor,ci=0.95, DHW.basedBSI = F){
  slopes = sapply(mods,function(x){sl = summary(x)$coefficients["x","Estimate"];return(sl)})
  slope.se = sapply(mods,function(x){sl = summary(x)$coefficients["x","Std. Error"];return(sl)})
  zscore2tail = qnorm(1-((1-ci)/2))
  slope.up = slopes + zscore2tail*slope.se
  slope.lo = slopes - zscore2tail*slope.se
  
  if(DHW.basedBSI == FALSE){
    P = 
      ggplot(data = data.frame(x = HTdays,
                               y = slopes,
                               ymin = slope.lo,
                               ymax = slope.up),
             aes(x,y)) + 
      geom_hline(yintercept = 0,colour="firebrick",
                 linetype="dashed", size=1)+
      geom_ribbon(aes(ymin=ymin,
                      ymax=ymax),
                  colour=NA,fill="grey80") + 
      geom_line(size=1,colour="dodgerblue1") + 
      labs(x = "Time during heat stress assay (days)",
           y = paste0("Slope of BSI ~ ",Predictor)) +
      theme_bw() + theme(panel.grid = element_blank())
  } else {
    P = 
      ggplot(data = data.frame(x = HTdhws,
                               y = slopes,
                               ymin = slope.lo,
                               ymax = slope.up),
             aes(x,y)) + 
      geom_hline(yintercept = 0,colour="firebrick",
                 linetype="dashed", size=1)+
      geom_ribbon(aes(ymin=ymin,
                      ymax=ymax),
                  colour=NA,fill="grey80") + 
      geom_line(size=1,colour="dodgerblue1") + 
      labs(x = bquote(Degree~heating~weeks~(degree*C-weeks)),
           y = paste0("Slope of BSI ~ ",Predictor)) +
      theme_bw() + theme(panel.grid = element_blank())
  }

  return(P)
  
}
BSItimepointPlotINLA = function(x, method = "lm", returnMod=F, DHW.basedBSI = F){ # or method="beta" for beta plot
  Ax.x = sub(".*\\$","",deparse(substitute(x)))
  Plist=list()
  ModList = list()
  if(DHW.basedBSI == FALSE){
    Nmods=16
  } else {
    Nmods=21
  }
  
  for(i in 1:Nmods){
    if(DHW.basedBSI == FALSE){
      Cols = c(paste0("BSI_08.",c("07","13","18","22","27","30")),
               paste0("BSI_09.",c("01","03","04","05","06","07","08","09","11","12")))
      BSI = TO[,which(colnames(TO) == Cols[i])]
    }
    if(DHW.basedBSI == TRUE){
      Cols = paste0("BSI.dhw_",c(0.0,0.5,1.1,1.6,2.2,2.7,3.2,3.8,4.3,4.8,5.4,5.9,6.5,7.0,7.5,8.1,8.6,9.2,9.7,10.2,10.8))
      BSI = TO[,which(colnames(TO) == Cols[i])]
    }
    #if(BSI.bin == T){
    #  BSI = ifelse(BSI >= 0.5,1,0)
    #}
    if(method=="lm"){
    Plist[[i]] =
      LMplotINLA(x,BSI,returnMod = F) + labs(y = Cols[i],x=Ax.x) + lims(y=c(0,1))
    
    # Running LMplotINLA to produce models
    ModList[[i]] = 
      LMplotINLA(x,BSI,returnMod = T)
    }
    if(method=="beta"){
      Plist[[i]] =
        BetaplotINLA(x,BSI,returnMod = F) + labs(y = Cols[i],x=Ax.x) + lims(y=c(0,1))
      
      # Running LMplotINLA to produce models
      ModList[[i]] = 
        BetaplotINLA(x,BSI,returnMod = T)
    }
  }
  if(returnMod == F){
    n = Nmods
    nr = 4
    nc = ceiling(n / 4)
    tot=nc*nr
    figs = c(1:n,rep(NA,tot-n))
    return(grid.arrange(grobs=Plist,
                        layout_matrix = matrix(figs,nrow=4,byrow = T)))  }
  if(returnMod == T){
    return(ModList)
  }
}
BSISlopePlotINLA = function(ModList,Predictor,DHW.basedBSI = F){
  slopes = as.data.frame(t(sapply(mods,function(x) {
    sl = data.frame(x$summary.fixed["x",c("mean", "0.025quant", "0.125quant","0.25quant", "0.75quant", "0.875quant","0.975quant")])
    colnames(sl)  =  c("mean", "selo.q95",   "selo.q75",  "selo.q50",  "seup.q50",  "seup.q75",  "seup.q95")
    return(unlist(sl))
    })))
  if(DHW.basedBSI == FALSE){
    slopes$HTdays = HTdays
    
    P = 
      ggplot() + 
      geom_hline(yintercept = 0,colour="firebrick",
                 linetype="dashed", size=1)+
      geom_ribbon(data = slopes, aes(x=HTdays, ymin=selo.q95, ymax=seup.q95),colour=NA,fill="grey80",alpha=0.5) +
      geom_ribbon(data = slopes, aes(x=HTdays, ymin=selo.q75, ymax=seup.q75),colour=NA,fill="grey70",alpha=0.5) + 
      geom_ribbon(data = slopes, aes(x=HTdays, ymin=selo.q50, ymax=seup.q50),colour=NA,fill="grey60",alpha=0.5) + 
      geom_line  (data = slopes, aes(x=HTdays, y=mean),
                  size=1,colour="dodgerblue1") + 
      labs(x = "Time during heat stress assay (days)",
           y = paste0("Slope of BSI ~ ",Predictor)) +
      theme_bw() + theme(panel.grid = element_blank())
    P
  } else {
    slopes$HTdhws = HTdhws
    
    P = 
      ggplot() + 
      geom_hline(yintercept = 0,colour="firebrick",
                 linetype="dashed", size=1)+
      geom_ribbon(data = slopes, aes(x=HTdhws, ymin=selo.q95, ymax=seup.q95),colour=NA,fill="grey80",alpha=0.5) +
      geom_ribbon(data = slopes, aes(x=HTdhws, ymin=selo.q75, ymax=seup.q75),colour=NA,fill="grey70",alpha=0.5) + 
      geom_ribbon(data = slopes, aes(x=HTdhws, ymin=selo.q50, ymax=seup.q50),colour=NA,fill="grey60",alpha=0.5) + 
      geom_line  (data = slopes, aes(x=HTdhws, y=mean),
                  size=1,colour="dodgerblue1") + 
      labs(x = bquote(Degree~heating~weeks~(degree*C-weeks)),
           y = paste0("Slope of BSI ~ ",Predictor)) +
      theme_bw() + theme(panel.grid = element_blank())
    P
  }
  
  return(P)
  
}


# ---------------------------------------------------- #
#            A)      Trait Exploration                 #
#                       Figure 1                       #
# ---------------------------------------------------- #
load(file="data processed/Figure 1A - Temperature Profiles.Rdata")
load(file="data processed/Figure 1B - DHW Profiles.Rdata")
load(file="data processed/Figure 1C - BSI Timecourse.Rdata")
load(file="data processed/Figure 1D - Symbiont-BSI Curves.Rdata")
load(file="data processed/Figure 1F - Fecundity.Rdata")

Plot0 = ggplot() + theme_void()
PlotList=align_plots(F1A,F1B,F1C,F1D,Plot0,F1F,
                     align="hv", axis="tblr")

pdf("outputs/Figure 1 - Trait Exploration.pdf", height=9, width = 8)
grid.arrange(grobs = PlotList,
             layout_matrix = rbind(c(1,2),
                                   c(5,5),
                                   c(3,4),
                                   c(5,5),
                                   c(5,6)),
             heights = c(10,1,10,1,10))
dev.off()



# ---------------------------------------------------- #
#     B)     Growth Metric Size Dependencies           #
#                       Figure S6                      #
# ---------------------------------------------------- #
TO = read.csv("data processed/Full_dataset.csv")
colnames(TO)

P1 = LMplot(logx = T, x = TO$Initial_Diameter.est,
            logy = F, y = TO$Grow.SAlive) + labs(y = "LiveSA growth\n(raw)")
P2 = LMplot(logx = T, x = TO$Initial_Diameter.est,
            logy = F, y = TO$Grow.Vol) + labs(y = "Volumetric growth\n(raw)")
P3 = LMplot(logx = T, x = TO$Initial_Diameter.est,
            logy = F, y = TO$Grow.SAlive.perc * 100) + labs(y = "LiveSA growth\n(%)")
P4 = LMplot(logx = T, x = TO$Initial_Diameter.est,
            logy = F, y = TO$Grow.Vol.perc * 100) + labs(y = "Volumetric growth\n(%)")
P5 = LMplot(logx = T, x = TO$Initial_Diameter.est,
            logy = F, y = TO$Grow.SAlive.Dstd) + labs(y = "LiveSA growth\n(corrected)")
P6 = LMplot(logx = T, x = TO$Initial_Diameter.est,
            logy = F, y = TO$Grow.Vol.Dstd) + labs(y = "Volumetric growth\n(corrected)")
PPlist = align_plots(P1,P2,P3,P4,P5,P6,align="hv", axis="tblr")
pdf("outputs/Figure S6 - Growth metric size dependencies.pdf", height = 10, width = 11)
grid.arrange(grobs = PPlist,
             layout_matrix = rbind(1:2,3:4,5:6))
dev.off()
LMlist = list(
  LM1 = summary(lm(Grow.SAlive ~ Initial_Diameter.est, data = TO)),
  LM2 = summary(lm(Grow.Vol ~ Initial_Diameter.est, data = TO)),
  LM3 = summary(lm(Grow.SAlive.perc ~ Initial_Diameter.est, data = TO)),
  LM4 = summary(lm(Grow.Vol.perc ~ Initial_Diameter.est, data = TO)),
  LM5 = summary(lm(Grow.SAlive.Dstd ~ Initial_Diameter.est, data = TO)),
  LM6 = summary(lm(Grow.Vol.Dstd ~ Initial_Diameter.est, data = TO)))
save(LMlist, file = "outputs/Figure S6 - Growth metric size dependency Models.Rdata")


# ---------------------------------------------------- #
#       C)      Partial Mortality analysis             #
#                       Figure S7                      #
# ---------------------------------------------------- #
TO$Part.Mort = ifelse(TO$Part.Mort!=0,"Yes","No")
TO$Part.Mort[is.na(TO$Part.Mort)] = "Unknown"
TO$Part.Mort = factor(TO$Part.Mort, levels = c("Yes","No","Unknown"))

PM1 = ggplot() + labs(y="Colony heat tolerance\n(average BSI)") + geom_boxplot(data = TO, fill = "grey50", aes(x = Part.Mort, 
                                                                                                               y = BSI.av)) + geom_bracket(y.position = 0.9, xmin = "Yes", xmax = "No", label = "P = 0.023"); PM1; PM1.mod = pairwise.wilcox.test(TO$BSI.av, TO$Part.Mort,p.adjust.method = "bonf"); PM1.mod
PM2 = ggplot() + labs(y="LiveSA growth\n(corrected)") + geom_boxplot(data = TO, fill = "grey50", aes(x = Part.Mort, 
                                                                                                           y = Grow.SAlive.Dstd)) + geom_bracket(y.position = 1200, xmin = "Yes", xmax = "No", label = "P = 0.006"); PM2; PM2.mod = pairwise.wilcox.test(TO$Grow.SAlive.Dstd, TO$Part.Mort,p.adjust.method = "bonf"); PM2.mod
PM3 = ggplot() + labs(y="Volumetric growth\n(corrected)") + geom_boxplot(data = TO, fill = "grey50", aes(x = Part.Mort, 
                                                                                                   y = Grow.Vol.Dstd)) + geom_bracket(y.position = 1500, xmin = "Yes", xmax = "No", label = "P = 0.005"); PM3; PM3.mod = TukeyHSD(aov(Grow.Vol.Dstd~Part.Mort,data=TO)); PM3.mod
PM4 = ggplot() + labs(y="Symbiont PC1") + geom_boxplot(data = TO, fill = "grey50", aes(x = Part.Mort, 
                                                                                       y = PC1)); PM4 ; PM4.mod = TukeyHSD(aov(PC1~Part.Mort,data=TO)); PM4.mod
PM5 = ggplot() + labs(y="Average egg\ndensity per polyp") + geom_boxplot(data = TO, fill = "grey50", aes(x = Part.Mort, 
                                                                                                         y = Eggs.av)); PM5; PM5.mod = TukeyHSD(aov(Eggs.av~Part.Mort,data=TO)); PM5.mod
PM6 = ggplot() + labs(y="Average egg volume") + geom_boxplot(data = TO, fill = "grey50", aes(x = Part.Mort, 
                                                                                             y = Egg.Vol)); PM6; PM6.mod = TukeyHSD(aov(Egg.Vol~Part.Mort,data=TO)); PM6.mod
PMlist = list(PM1,PM2,PM3,PM4,PM5, PM6)
PMlist = lapply(PMlist,"+",theme_bw())
PMlist = lapply(PMlist,"+",theme(axis.title.x = element_blank(),
                                 panel.grid = element_blank(),
                                 panel.background = element_rect(fill="grey90")))
PMlist = align_plots(PMlist[[1]], PMlist[[2]], PMlist[[3]], PMlist[[4]], PMlist[[5]], PMlist[[6]],  align="v", axis="tblr")
pdf("outputs/Figure S7 - Partial Mortality Relationships.pdf",width = 9, height = 5)
grid.arrange(grobs = PMlist,
             layout_matrix = rbind(c(1:3),c(4:6)),
             top = textGrob(expression(bold("Partial mortality relationships"))),
             bottom = "Partial mortality")
dev.off()
PMlist = list(PM1.mod, PM2.mod, PM3.mod,
               PM4.mod, PM5.mod, PM6.mod)
save(PMlist, file = "outputs/Figure S7 - Partial Mortality Relationship Models.Rdata")


# ------------------------------------------------------------ #
# D)   Heat tolerance - trait trade-off or co-benefit analysis #
#                          Figures 2, S8, S9                   #
# ------------------------------------------------------------ #

FS9=
  LMplotINLA(x = TO$Grow.SAlive.Dstd[TO$Grow.SAlive.Dstd>=0], 
             y = TO$BSI.av[TO$Grow.SAlive.Dstd>=0]) + 
  labs(x = bquote(Live~surface~area~growth~(cm^2/yr)),
       y = "Colony heat tolerance\n(average BSI)")+ 
  theme(axis.title.y = element_blank())
FS9

F2A=
  LMplotINLA(x = TO$Grow.SAlive.Dstd, 
             y = TO$BSI.av) + 
  labs(x = bquote(Live~surface~area~growth~(cm^2/yr)),
       y = "Colony heat tolerance\n(average BSI)")+ 
  theme(axis.title.y = element_blank())
F2A

F2B=  
  LMplotINLA(x = TO$Grow.Vol.Dstd, 
             y = TO$BSI.av) + 
  labs(x = bquote(Volumetric~growth~(cm^3/yr)),
       y = "Colony heat tolerance\n(average BSI)") +
  theme(axis.title.y = element_blank())
F2C=  
  LMplotINLA(x = TO$Eggs.per.colony/100000, 
             y = TO$BSI.av) + 
  labs(x = expression("Eggs per colony (" %*% "10"^"5"*")"),
       y = "Colony heat tolerance\n(average BSI)") + 
  theme(axis.title.y = element_blank(),
        axis.text.y = element_blank())
F2D=  
  LMplotINLA(x = TO$Egg.Vol.per.colony, 
             y = TO$BSI.av) + 
  labs(x = bquote(Total~egg~volume~per~colony~(cm^3)),
       y = "Colony heat tolerance\n(average BSI)") + 
  theme(axis.title.y = element_blank(),
        axis.text.y = element_blank())

F2 = align_plots(F2A, F2B, F2C, F2D, align="vh", axis="tblr")

pdf("outputs/Figure 2 - Heat tolerance Trait Relationships.pdf",width=9,height=7)
grid.arrange(grobs = F2,
             layout_matrix = rbind(c(1,3),
                                   c(2,4)),
             left = "Colony heat tolerance (average BSI)")  
dev.off()

# Outlier test for fecundity metrics
# Eggs per colony < 1e6 (top one colony)
  LMplotINLA(x = TO$Eggs.per.colony[TO$Eggs.per.colony <1e6]/100000, 
             y = TO$BSI.av[TO$Eggs.per.colony <1e6]) + 
  labs(x = expression("Eggs per colony (" %*% "10"^"5"*")"),
       y = "Colony heat tolerance\n(average BSI)") + 
  theme(axis.title.y = element_blank(),
        axis.text.y = element_blank())

  LMplotINLA(x = TO$Egg.Vol.per.colony[TO$Eggs.per.colony <1e6], 
             y = TO$BSI.av[TO$Eggs.per.colony <1e6]) + 
  labs(x = bquote(Total~egg~volume~per~colony~(cm^3)),
       y = "Colony heat tolerance\n(average BSI)") + 
  theme(axis.title.y = element_blank(),
        axis.text.y = element_blank())



# Bayesian posterior distribution probabilities
# Figure S8 and S9
Ilist = list(
  I1 =   LMplotINLA(x = TO$Grow.SAlive.Dstd, y = TO$BSI.av, returnMod = T),
  I2 =   LMplotINLA(x = TO$Grow.Vol.Dstd, y = TO$BSI.av, returnMod = T),
  I3 =   LMplotINLA(x = TO$Eggs.per.colony/100000, y = TO$BSI.av, returnMod = T),
  I4 =   LMplotINLA(x = TO$Egg.Vol.per.colony, y = TO$BSI.av, returnMod = T),
  I5 =   LMplotINLA(x = TO$Grow.SAlive.Dstd[TO$Grow.SAlive.Dstd>=0], y = TO$BSI.av[TO$Grow.SAlive.Dstd>=0], returnMod = T))
IPlist = list()
tit = c("BSI ~ Live Surface Area Growth",
        "BSI ~ Volumetric growth",
        "BSI ~ Total colony egg production",
        "BSI ~ Total Colony egg volume",
        "BSI ~ Live Surface Area Growth (positive growth only)")
for(i in 1:5){
  Imod = Ilist[[i]]
  inds = sort(order(abs(Imod$marginals.fixed$x[,1]))[1:2])
  Sinds = sort(inds)
  NN = nrow(Imod$marginals.fixed$x)
  dd = as.data.frame(Imod$marginals.fixed$x[Sinds,])
  mod = lm(y~x, data = dd)
  yy = predict(mod, data.frame(x=0))
  PD = as.matrix(data.frame(x=c(Imod$marginals.fixed$x[1:Sinds[1],1], 0, Imod$marginals.fixed$x[Sinds[2]:NN,1]),
                            y=c(Imod$marginals.fixed$x[1:Sinds[1],2], yy, Imod$marginals.fixed$x[Sinds[2]:NN,2])))
  # main section of posterior distribution that includes the average of the distribution
  PDM = as.matrix(data.frame(x=c(0,0, Imod$marginals.fixed$x[Sinds[2]:NN,1]),
                             y=c(0,yy, Imod$marginals.fixed$x[Sinds[2]:NN,2])))

  PDA = sf::st_area(st_polygon(list(rbind(PD,PD[1,]))), which="Euclidean")
  # plot(st_polygon(list(rbind(PD,PD[1,]))))
  PDMA = sf::st_area(st_polygon(list(rbind(PDM,PDM[1,]))), which="Euclidean")
  probability = round(100*(1 - (PDA - PDMA)/PDA))
  probability
  
  P1 =
    ggplot() + 
    geom_polygon(data = as.data.frame(PD), aes(x=x,y=y), fill = "grey90", colour = "grey80", size= 1) + 
    geom_polygon(data = as.data.frame(PDM), aes(x=x,y=y), fill = "dodgerblue", colour = "dodgerblue1", size=1) + 
    geom_vline(xintercept = 0,linetype="dashed", colour="firebrick",size=1) +
    labs(x = "Slope value",
         y = bquote(pi(Beta[1]*"|"*y)),
         title = tit[i]) +
    annotate(geom="text", 
             x = quantile(range(PD[,1]),probs=0.25), 
             y = quantile(range(PD[,2]),probs=0.8), 
             label = paste0(probability, "% probability of\npositive slope"), 
             hjust = 0.5, vjust = 1) +
    theme_bw()   +
    theme(plot.title = element_text(hjust = 0.5))
  IPlist = c(IPlist, list(P1))
}

pdf("outputs/Figure S8 - Probability of Positive slope all traits.pdf",width=9,height=7)
grid.arrange(grobs = IPlist[-5],
             layout_matrix = rbind(c(1,3),
                                   c(2,4)))  
dev.off()


FS9list=list(FS9, IPlist[[5]])
FS9list[1] = lapply(FS9list[1], function(x){x=x + 
  labs(y="average BSI\n", title="Positive growth colonies only") + 
  theme(axis.title.y = element_text(angle=90),
        plot.title = element_text(hjust=0.5))})
pdf("outputs/Figure S9 - Positive growth colonies only.pdf",width=9,height=3.5)
grid.arrange(grobs = FS9list,
             layout_matrix = rbind(1:2))  
dev.off()

# ----------------------------------------------------------------------- #
#   E)   Progression of BSI-trait relationships throughout heat stress    #
#                            Figure 3, S7, S8                             #
# ----------------------------------------------------------------------- #
mods = BSItimepointPlotINLA(x=MyStd(TO$Grow.SAlive.Dstd), # TO$Grow.SAlive.Dstd/10000, #
                          method="lm", returnMod = T, DHW.basedBSI = T)
  P1 = BSISlopePlotINLA(mods,"StdGrowth.SAlive.Dstd", DHW.basedBSI = T) +
    scale_x_continuous(limits = range(HTdhws)+c(-0.26,0.3), expand=c(0,0),
                       breaks = c(0,4,8,12))
    
  
  BSI.DHWs = colMeans(TO[,which(grepl("BSI.dhw_",colnames(TO)))], na.rm = T)
  polys = c(HTdhws[1]-(diff(HTdhws[1:2])),HTdhws,HTdhws[length(HTdhws)]+(diff(HTdhws[(length(HTdhws)-1):length(HTdhws)])))
  polys = rowMeans(cbind(polys[-1],polys[-length(polys)])) 
  polys2 = rep(HTdhws,each=4)
  polys2[seq(1,length(polys2),by=4)] = polys[-length(polys)]
  polys2[seq(2,length(polys2),by=4)] = polys[-1]
  polys2[seq(3,length(polys2),by=4)] = polys[-1]
  polys2[seq(4,length(polys2),by=4)] = polys[-length(polys)]
  BSItimecourse = data.frame(DHW = polys2,
                             BSI.av = rep(BSI.DHWs,each=4),
                             y = rep(c(1,1,0,0),length(HTdhws)))
  P = 
    ggplot() + 
    geom_polygon(data = BSItimecourse,
                 aes(x=DHW,y=y,fill=BSI.av,group = factor(BSI.av)),
                 colour="black", size = 0.35) +
    scale_fill_gradientn(colours = c("coral2","white","dodgerblue4"),
                         limits = c(0,1)) +
    ylim(c(0,2.5)) +
    scale_x_continuous(limits = range(HTdhws)+c(-0.26,0.3), expand=c(0,0)) +
    guides(fill = guide_colourbar(title = "Population average BSI",
                                  title.position="top",
                                  title.hjust = 0.5,
                                  title.vjust = 0,
                                  barwidth = 10,
                                  barheight = 0.5,
                                  label.vjust = 1,
                                  ticks.colour = "black",
                                  frame.colour="black",
                                  breaks = c(0,0.5,1))) +
    theme_bw() + 
    coord_cartesian(clip="off") +
    theme(panel.grid = element_blank(),
          panel.border = element_blank(),
          axis.text = element_blank(),
          axis.ticks = element_blank(),
          axis.title = element_blank(),
          legend.background = element_blank(),
          legend.title.align = 0.5,
          legend.position = c(0.5, 0.75),
          # legend.position = "top",
          legend.direction = "horizontal")
P
Ps = align_plots(P, P1, align="v", axis="tblr")
 
pdf("outputs/Figure 3 - Progression of BSI-growth slope through experiment.pdf",width=6.5,height=4.7)
 grid.arrange(grobs = Ps,
              layout_matrix = cbind(1:2),
              heights = c(1,4.2))
dev.off()



ALLMODELS = mods
IPlist = list()
probabilityNegSlope = c()
tit = paste0("DHW = ", HTdhws)
for(i in 1:length(tit)){
  Imod = ALLMODELS[[i]]
  inds = sort(order(abs(Imod$marginals.fixed$x[,1]))[1:2])
  Sinds = sort(inds)
  NN = nrow(Imod$marginals.fixed$x)
  dd = as.data.frame(Imod$marginals.fixed$x[Sinds,])
  mod = lm(y~x, data = dd)
  yy = predict(mod, data.frame(x=0))
  PD = as.matrix(data.frame(x=c(Imod$marginals.fixed$x[1:Sinds[1],1], 0, Imod$marginals.fixed$x[Sinds[2]:NN,1]),
                            y=c(Imod$marginals.fixed$x[1:Sinds[1],2], yy, Imod$marginals.fixed$x[Sinds[2]:NN,2])))
  # main section of posterior distribution that includes the average of the distribution
  if(Sinds[1]>NN/2){
    PDM = as.matrix(data.frame(x=c(Imod$marginals.fixed$x[1:Sinds[1],1], 0,0),
                               y=c(Imod$marginals.fixed$x[1:Sinds[1],2], yy,0)))
  } else {
    PDM = as.matrix(data.frame(x=c(0,0, Imod$marginals.fixed$x[Sinds[2]:NN,1]),
                               y=c(0,yy, Imod$marginals.fixed$x[Sinds[2]:NN,2])))
  }
  
  PDA = sf::st_area(st_polygon(list(rbind(PD,PD[1,]))), which="Euclidean")
  PDMA = sf::st_area(st_polygon(list(rbind(PDM,PDM[1,]))), which="Euclidean")
  probability = round(100*(1 - (PDA - PDMA)/PDA))
  probabilityNegSlope[i] = probability
  
  Px = 
    ggplot() + 
    geom_polygon(data = as.data.frame(PD), aes(x=x,y=y), fill = "grey90", colour = "grey80", size= 1) + 
    geom_polygon(data = as.data.frame(PDM), aes(x=x,y=y), fill = "dodgerblue", colour = "dodgerblue1", size=1) + 
    geom_vline(xintercept = 0,linetype="dashed", colour="firebrick",size=1) +
    labs(x = "Slope value",
         y = bquote(pi(Beta[1]*"|"*y)),
         title = tit[i]) +
    annotate(geom="text", 
             x = quantile(range(PD[,1]),probs=0.25), 
             y = quantile(range(PD[,2]),probs=0.8), 
             label = paste0(probability, "% probability of\ntrade-off"), 
             hjust = 0.5, vjust = 1) +
    theme_bw()   +
    theme(plot.title = element_text(hjust = 0.5))
  IPlist = c(IPlist, list(Px))
}

FS11A = 
ggplot() + 
  geom_line(data = data.frame(probabilityNegSlope = probabilityNegSlope,
                              dhw = HTdhws),
            aes(x=dhw,
                y=probabilityNegSlope/100),
            size=1, colour="dodgerblue") + 
  geom_hline(yintercept = 0.5, size=1,colour = "firebrick",linetype="dashed") + 
  scale_x_continuous(breaks = c(0,4,8)) + 
  scale_y_continuous(breaks=c(0,0.5,1), limits = c(0,1)) +
  labs(x =expression(paste("DHW throughout exposure ("*degree*C*"-weeks)")),
       y = "Probability of positive slope",
       title = "BSI ~ SAlive growth") +
  theme_bw() + 
  theme(panel.grid = element_blank(),
        plot.title = element_text(hjust=0.5))

#


# --------------------------------------------------------------------- #
# BSI vs Volumetric Growth throughout DHW exposure
# --------------------------------------------------------------------- #

mods = BSItimepointPlotINLA(x=MyStd(TO$Grow.Vol.Dstd), # TO$Grow.SAlive.Dstd/10000, #
                            method="lm", returnMod = T, DHW.basedBSI = T)
P2 = BSISlopePlotINLA(mods,"StdGrowth.Vol.Dstd", DHW.basedBSI = T) +
  scale_x_continuous(limits = range(HTdhws)+c(-0.26,0.3), expand=c(0,0),
                     breaks = c(0,4,8,12))
P2
Ps2 = align_plots(P, P2, align="v", axis="tblr")


ALLMODELS = mods
IPlist = list()
probabilityNegSlope = c()
tit = paste0("DHW = ", HTdhws)
for(i in 1:length(tit)){
  Imod = ALLMODELS[[i]]
  inds = sort(order(abs(Imod$marginals.fixed$x[,1]))[1:2])
  Sinds = sort(inds)
  NN = nrow(Imod$marginals.fixed$x)
  dd = as.data.frame(Imod$marginals.fixed$x[Sinds,])
  mod = lm(y~x, data = dd)
  yy = predict(mod, data.frame(x=0))
  PD = as.matrix(data.frame(x=c(Imod$marginals.fixed$x[1:Sinds[1],1], 0, Imod$marginals.fixed$x[Sinds[2]:NN,1]),
                            y=c(Imod$marginals.fixed$x[1:Sinds[1],2], yy, Imod$marginals.fixed$x[Sinds[2]:NN,2])))
  # main section of posterior distribution that includes the average of the distribution
  if(Sinds[1]>NN/2){
    PDM = as.matrix(data.frame(x=c(Imod$marginals.fixed$x[1:Sinds[1],1], 0,0),
                               y=c(Imod$marginals.fixed$x[1:Sinds[1],2], yy,0)))
  } else {
    PDM = as.matrix(data.frame(x=c(0,0, Imod$marginals.fixed$x[Sinds[2]:NN,1]),
                               y=c(0,yy, Imod$marginals.fixed$x[Sinds[2]:NN,2])))
  }
  
  PDA = sf::st_area(st_polygon(list(rbind(PD,PD[1,]))), which="Euclidean")
  PDMA = sf::st_area(st_polygon(list(rbind(PDM,PDM[1,]))), which="Euclidean")
  probability = round(100*(1 - (PDA - PDMA)/PDA))
  probabilityNegSlope[i] = probability
  
  Px = 
    ggplot() + 
    geom_polygon(data = as.data.frame(PD), aes(x=x,y=y), fill = "grey90", colour = "grey80", size= 1) + 
    geom_polygon(data = as.data.frame(PDM), aes(x=x,y=y), fill = "dodgerblue", colour = "dodgerblue1", size=1) + 
    geom_vline(xintercept = 0,linetype="dashed", colour="firebrick",size=1) +
    labs(x = "Slope value",
         y = bquote(pi(Beta[1]*"|"*y)),
         title = tit[i]) +
    annotate(geom="text", 
             x = quantile(range(PD[,1]),probs=0.25), 
             y = quantile(range(PD[,2]),probs=0.8), 
             label = paste0(probability, "% probability of\nnegative slope"), 
             hjust = 0.5, vjust = 1) +
    theme_bw()   +
    theme(plot.title = element_text(hjust = 0.5))
  IPlist = c(IPlist, list(Px))
}

FS11C = 
  ggplot() + 
  geom_line(data = data.frame(probabilityNegSlope = probabilityNegSlope,
                              dhw = HTdhws),
            aes(x=dhw,
                y=probabilityNegSlope/100),
            size=1, colour="dodgerblue") + 
  geom_hline(yintercept = 0.5, size=1,colour = "firebrick",linetype="dashed") + 
  scale_x_continuous(breaks = c(0,4,8)) + 
  scale_y_continuous(breaks=c(0,0.5,1), limits = c(0,1)) +
  labs(x =expression(paste("DHW throughout exposure ("*degree*C*"-weeks)")),
       y = "Probability of positive slope",
       title = "BSI ~ Volumetric growth") +
  theme_bw() + 
  theme(panel.grid = element_blank(),
        plot.title = element_text(hjust=0.5))

#










# --------------------------------------------------------------------- #
# BSI vs Colony Fecundity throughout DHW exposure
# --------------------------------------------------------------------- #

mods = BSItimepointPlotINLA(x=MyStd(TO$Eggs.per.colony), # TO$Grow.SAlive.Dstd/10000, #
                            method="lm", returnMod = T, DHW.basedBSI = T)
P3 = BSISlopePlotINLA(mods,"StdEggs.per.colony", DHW.basedBSI = T) +
  scale_x_continuous(limits = range(HTdhws)+c(-0.26,0.3), expand=c(0,0),
                     breaks = c(0,4,8,12))
P3
Ps3 = align_plots(P, P3, align="v", axis="tblr")

ALLMODELS = mods
IPlist = list()
probabilityNegSlope = c()
tit = paste0("DHW = ", HTdhws)
for(i in 1:length(tit)){
  Imod = ALLMODELS[[i]]
  inds = sort(order(abs(Imod$marginals.fixed$x[,1]))[1:2])
  Sinds = sort(inds)
  NN = nrow(Imod$marginals.fixed$x)
  dd = as.data.frame(Imod$marginals.fixed$x[Sinds,])
  mod = lm(y~x, data = dd)
  yy = predict(mod, data.frame(x=0))
  PD = as.matrix(data.frame(x=c(Imod$marginals.fixed$x[1:Sinds[1],1], 0, Imod$marginals.fixed$x[Sinds[2]:NN,1]),
                            y=c(Imod$marginals.fixed$x[1:Sinds[1],2], yy, Imod$marginals.fixed$x[Sinds[2]:NN,2])))
  # main section of posterior distribution that includes the average of the distribution
  if(Sinds[1]>NN/2){
    PDM = as.matrix(data.frame(x=c(Imod$marginals.fixed$x[1:Sinds[1],1], 0,0),
                               y=c(Imod$marginals.fixed$x[1:Sinds[1],2], yy,0)))
  } else {
    PDM = as.matrix(data.frame(x=c(0,0, Imod$marginals.fixed$x[Sinds[2]:NN,1]),
                               y=c(0,yy, Imod$marginals.fixed$x[Sinds[2]:NN,2])))
  }
  
  PDA = sf::st_area(st_polygon(list(rbind(PD,PD[1,]))), which="Euclidean")
  PDMA = sf::st_area(st_polygon(list(rbind(PDM,PDM[1,]))), which="Euclidean")
  probability = round(100*(1 - (PDA - PDMA)/PDA))
  probabilityNegSlope[i] = probability
  
  Px = 
    ggplot() + 
    geom_polygon(data = as.data.frame(PD), aes(x=x,y=y), fill = "grey90", colour = "grey80", size= 1) + 
    geom_polygon(data = as.data.frame(PDM), aes(x=x,y=y), fill = "dodgerblue", colour = "dodgerblue1", size=1) + 
    geom_vline(xintercept = 0,linetype="dashed", colour="firebrick",size=1) +
    labs(x = "Slope value",
         y = bquote(pi(Beta[1]*"|"*y)),
         title = tit[i]) +
    annotate(geom="text", 
             x = quantile(range(PD[,1]),probs=0.25), 
             y = quantile(range(PD[,2]),probs=0.8), 
             label = paste0(probability, "% probability of\nnegative slope"), 
             hjust = 0.5, vjust = 1) +
    theme_bw()   +
    theme(plot.title = element_text(hjust = 0.5))
  IPlist = c(IPlist, list(Px))
}

# ProbNegSlp4 = 
FS11B = 
  ggplot() + 
  geom_line(data = data.frame(probabilityNegSlope = probabilityNegSlope,
                              dhw = HTdhws),
            aes(x=dhw,
                y=probabilityNegSlope/100),
            size=1, colour="dodgerblue") + 
  geom_hline(yintercept = 0.5, size=1,colour = "firebrick",linetype="dashed") + 
  scale_x_continuous(breaks = c(0,4,8)) + 
  scale_y_continuous(breaks=c(0,0.5,1), limits = c(0,1)) +
  labs(x =expression(paste("DHW throughout exposure ("*degree*C*"-weeks)")),
       y = "Probability of positive slope",
       title = "BSI ~ Eggs per colony") +
  theme_bw() + 
  theme(panel.grid = element_blank(),
        plot.title = element_text(hjust=0.5))
FS11B
#






# --------------------------------------------------------------------- #
# BSI vs Colony Fecundity throughout DHW exposure
# --------------------------------------------------------------------- #

mods = BSItimepointPlotINLA(x=MyStd(TO$Egg.Vol.per.colony), # TO$Grow.SAlive.Dstd/10000, #
                            method="lm", returnMod = T, DHW.basedBSI = T)
P4 = BSISlopePlotINLA(mods,"StdTotal.Egg.Vol", DHW.basedBSI = T) +
  scale_x_continuous(limits = range(HTdhws)+c(-0.26,0.3), expand=c(0,0),
                     breaks = c(0,4,8,12))
P4
Ps4 = align_plots(P, P4, align="v", axis="tblr")

ALLMODELS = mods
IPlist = list()
probabilityNegSlope = c()
tit = paste0("DHW = ", HTdhws)
for(i in 1:length(tit)){
  Imod = ALLMODELS[[i]]
  inds = sort(order(abs(Imod$marginals.fixed$x[,1]))[1:2])
  Sinds = sort(inds)
  NN = nrow(Imod$marginals.fixed$x)
  dd = as.data.frame(Imod$marginals.fixed$x[Sinds,])
  mod = lm(y~x, data = dd)
  yy = predict(mod, data.frame(x=0))
  PD = as.matrix(data.frame(x=c(Imod$marginals.fixed$x[1:Sinds[1],1], 0, Imod$marginals.fixed$x[Sinds[2]:NN,1]),
                            y=c(Imod$marginals.fixed$x[1:Sinds[1],2], yy, Imod$marginals.fixed$x[Sinds[2]:NN,2])))
  # main section of posterior distribution that includes the average of the distribution
  if(Sinds[1]>NN/2){
    PDM = as.matrix(data.frame(x=c(Imod$marginals.fixed$x[1:Sinds[1],1], 0,0),
                               y=c(Imod$marginals.fixed$x[1:Sinds[1],2], yy,0)))
  } else {
    PDM = as.matrix(data.frame(x=c(0,0, Imod$marginals.fixed$x[Sinds[2]:NN,1]),
                               y=c(0,yy, Imod$marginals.fixed$x[Sinds[2]:NN,2])))
  }
  
  PDA = sf::st_area(st_polygon(list(rbind(PD,PD[1,]))), which="Euclidean")
  PDMA = sf::st_area(st_polygon(list(rbind(PDM,PDM[1,]))), which="Euclidean")
  probability = round(100*(1 - (PDA - PDMA)/PDA))
  probabilityNegSlope[i] = probability
  
  Px = 
    ggplot() + 
    geom_polygon(data = as.data.frame(PD), aes(x=x,y=y), fill = "grey90", colour = "grey80", size= 1) + 
    geom_polygon(data = as.data.frame(PDM), aes(x=x,y=y), fill = "dodgerblue", colour = "dodgerblue1", size=1) + 
    geom_vline(xintercept = 0,linetype="dashed", colour="firebrick",size=1) +
    labs(x = "Slope value",
         y = bquote(pi(Beta[1]*"|"*y)),
         title = tit[i]) +
    annotate(geom="text", 
             x = quantile(range(PD[,1]),probs=0.25), 
             y = quantile(range(PD[,2]),probs=0.8), 
             label = paste0(probability, "% probability of\nnegative slope"), 
             hjust = 0.5, vjust = 1) +
    theme_bw()   +
    theme(plot.title = element_text(hjust = 0.5))
  IPlist = c(IPlist, list(Px))
}

# ProbNegSlp5 = 
FS11D = 
  ggplot() + 
  geom_line(data = data.frame(probabilityNegSlope = probabilityNegSlope,
                              dhw = HTdhws),
            aes(x=dhw,
                y=probabilityNegSlope/100),
            size=1, colour="dodgerblue") + 
  geom_hline(yintercept = 0.5, size=1,colour = "firebrick",linetype="dashed") + 
  scale_x_continuous(breaks = c(0,4,8)) + 
  scale_y_continuous(breaks=c(0,0.5,1), limits = c(0,1)) +
  labs(x =expression(paste("DHW throughout exposure ("*degree*C*"-weeks)")),
       y = "Probability of positive slope",
       title = "BSI ~ Total egg volume") +
  theme_bw() + 
  theme(panel.grid = element_blank(),
        plot.title = element_text(hjust=0.5))
FS11D

#

FS10 = align_plots(P, P2, P3, P4, align="v", axis="tblr")
pdf("outputs/Figure S10 - Progression of BSI-trait slopes through experiment.pdf",height=11,width = 6)
grid.arrange(grobs = FS10,
             layout_matrix = cbind(1:4),
             heights = c(1,4,4,4))
dev.off()




#
pdf("outputs/Figure S11 - Probability of Positive DHW-trait slope throughout experiment.pdf",height=8,width = 9)
grid.arrange(grobs = list(FS11A, FS11B, FS11C, FS11D),
             layout_matrix = rbind(1:2,
                                   3:4))
dev.off()



# 

# ---------------------------------------------------- #
#     F)     Bleaching and mortality Onset             #
#                   Figure S12                         #
# ---------------------------------------------------- #
Plist=list()
# P2list=list()
# Bresponses = c(1 - (1*0.5 + 0*0.5)/4,# 2,2 nubbins healthy, partially bleached 
#                1 - (1*0.75 + 0*0.25)/4,# 1,3 nubbins healthy, partially bleached 
#                1 - (1*0.75 + 0*0.25)/4) # 4 nubbins partially bleached 
Bresponses = rev(seq(0.75,0.8,by=0.01))
# Mresponses = rev(seq(0.25,0.3,by=0.01))
Bps = c()
# Mps = c()
Bslps = c()
# Mslps = c()
# 10th and 90th percentiles of Growth
percentiles = quantile(TO$Grow.SAlive.Dstd, probs = c(0.1,0.9), na.rm = T)
Percs = data.frame(Grow.SAlive.Dstd=percentiles)
for(i in 1:length(Bresponses)){
  Bresponse = Bresponses[i]
  # Mresponse = Mresponses[i]
  
# response=0.85
ON = TO[!is.na(match(colnames(TO), c("Colony_ID", "BSI.av", "Grow.SAlive.Dstd" , colnames(TO)[grep("dhw_",colnames(TO))])))]
colnames(ON)
ON = gather(ON,"DHW","BSI",colnames(ON)[-c(1,2,ncol(ON))])
ON$DHW = as.numeric(sub(".*_","",ON$DHW))
# 
# ggplot() + 
#   geom_line(data=ON,
#             aes(x=DHW,
#                 y=BSI,
#                 group=Colony_ID,
#                 colour=Grow.SAlive.Dstd)) + 
#   theme(panel.grid = element_blank())

ON = ON %>%
  group_by(Colony_ID, BSI.av, Grow.SAlive.Dstd) %>%
  summarise(bleachingDHW = DHW[which(BSI<=Bresponse)[1]],
            # mortalityDHW = DHW[which(BSI<=Mresponse)[1]]
            )
ON$GrowthType=ifelse(ON$Grow.SAlive.Dstd>=0,"(+) growth)","(-) growth")
P1 = 
  ggplot(data = cbind(ON, BSI=paste0("BSI = ",Bresponse)),
         aes(x=Grow.SAlive.Dstd,
             y=bleachingDHW)) + 
  geom_point() + 
  geom_smooth(method="lm")+
  labs(y = "",#bquote(Bleaching~DHW~(degree*C-weeks)),
       # title = bquote(Bleaching~BSI==.(Bresponse)),
       x = "") + #bquote(Live~surface~area~growth~(cm^2/yr))) +
  stat_poly_eq(aes(label =  paste(after_stat(p.value.label),
                                  sep =  "*\", \"*")), # ", ")),
               formula = y ~ x) +
  facet_grid(~BSI) + 
  theme_bw() +
  theme(panel.grid = element_blank(),
        axis.title.x = element_blank(),
        axis.text = element_blank(),
        plot.title = element_text(hjust=0.5))
P1

Plist[[i]] = P1

mod = lm(bleachingDHW ~ Grow.SAlive.Dstd, data = ON)
Percs[i+1] = predict(mod, newdata = Percs)
colnames(Percs)[i+1] = paste0("BleachingDose_BMI-",Bresponse)
sum = summary(mod)
sum
Bps[i]=sum$coefficients[2,4]
Bslps[i]=sum$coefficients[2,1]

# mod = lm(mortalityDHW ~ Grow.SAlive.Dstd, data = ON)
# sum = summary(mod)
# sum
# Mps[i]=sum$coefficients[2,4]
# Mslps[i]=sum$coefficients[2,1]
# 
# dat = cbind(ON[!is.na(ON$GrowthType),], BSI=paste0("BSI = ",Bresponse))
# print(t.test(bleachingDHW ~ GrowthType, data=dat))
# P2 = 
#   ggplot(data = dat,
#          aes(x=GrowthType,
#              y=bleachingDHW)) + 
#   geom_boxplot(fill="grey90") + 
#   # geom_smooth(method="lm")+
#   labs(x="",y="")+
#   # labs(y = "",#bquote(Bleaching~DHW~(degree*C-weeks)),
#   #      # title = bquote(Bleaching~BSI==.(Bresponse)),
#   #      x = "") + #bquote(Live~surface~area~growth~(cm^2/yr))) +
#   stat_poly_eq(aes(label =  paste(after_stat(p.value.label),
#                                   sep =  "*\", \"*")), # ", ")),
#                formula = y ~ x) +
#   facet_grid(~BSI) + 
#   theme_bw() +
#   theme(panel.grid = element_blank(),
#         axis.title.x = element_blank(),
#         axis.text = element_blank(),
#         plot.title = element_text(hjust=0.5))
# P2
# P2list[[i]] = P2

}

# Equates to what shift in DHW tolerance between 10th and 90th percentiles of Growth??
Percs[2,-1] - Percs[1,-1]

ggplot(data = data.frame(BSI=Bresponses,
                         slope=Bslps,
                         pvalue=Bps)) + 
  geom_line(aes(x=BSI,
                y=pvalue)) + 
  geom_hline(yintercept = 0.05, linetype="dashed", colour="firebrick") + 
  theme_bw() +
  theme(panel.grid = element_blank())

# ggplot(data = data.frame(BSI=Mresponses,
#                          slope=Mslps,
#                          pvalue=Mps)) + 
#   geom_line(aes(x=BSI,
#                 y=pvalue)) + 
#   geom_hline(yintercept = 0.05, linetype="dashed", colour="firebrick") + 
#   theme_bw() +
#   theme(panel.grid = element_blank())

Plist2 = Plist
Plist2 = lapply(Plist2, function(x){ x = x + 
  scale_y_continuous(breaks=seq(2,8,by=2), limits=c(2,9.5),
                     labels = c("","4","","8"))
})
Plist2[c(1,4)] = lapply(Plist2[c(1,4)], function(x){ x = x + 
  theme(axis.text.y = element_text())
})
Plist2[4:6] = lapply(Plist2[4:6], function(x){ x = x + 
  theme(axis.text.x = element_text())
})
Plist2 = align_plots(Plist2[[1]], Plist2[[2]], Plist2[[3]], Plist2[[4]], Plist2[[5]], Plist2[[6]],
                     align="hv", axis="tblr")
pdf("outputs/Figure S12 Bleaching Dosage versus Growth.pdf", width = 9, height = 4)
grid.arrange(grobs = Plist2,
             layout_matrix = rbind(c(1:3),
                                   c(4:6)),
             bottom = textGrob(label=bquote(Live~surface~area~growth~(cm^2/yr))),
             left = textGrob(label=bquote(Bleaching~DHW~(degree*C-weeks)), rot = 90))
dev.off()



# 
# P2list2 = P2list
# P2list2 = lapply(P2list2, function(x){ x = x + 
#   scale_y_continuous(breaks=seq(2,8,by=2), limits=c(2,9.5),
#                      labels = c("","4","","8"))
# })
# P2list2[c(1,4)] = lapply(P2list2[c(1,4)], function(x){ x = x + 
#   theme(axis.text.y = element_text())
# })
# P2list2[4:6] = lapply(P2list2[4:6], function(x){ x = x + 
#   theme(axis.text.x = element_text())
# })
# P2list2 = align_plots(P2list2[[1]], P2list2[[2]], P2list2[[3]], P2list2[[4]], P2list2[[5]], P2list2[[6]],
#                      align="hv", axis="tblr")
# grid.arrange(grobs = P2list2,
#              layout_matrix = rbind(c(1:3),
#                                    c(4:6)),
#              bottom = textGrob(label=bquote(Live~surface~area~growth~(cm^2/yr))),
#              left = textGrob(label=bquote(Bleaching~DHW~(degree*C-weeks)), rot = 90))
# 

